<?php
/**
 * The template for displaying archive pages.
 *
 * @link http://codex.wordpress.org/Template_Hierarchy
 *
 * @package     Sarmaya
 * @author      Amjad Ali
 * @license     http://www.gnu.org/licenses/gpl-3.0.html GNU Public License
 */

get_header(); ?>

<?php if (is_author()) { 
  $author = get_queried_object();
  $author_id = $author->ID;
  ?>
 <div class="page-main-title">
   <div class="container">
     <div class="row">
      <div class="col-lg-3">
        <img src="<?php echo esc_url(get_avatar_url( $author_id, array('size' => '550'))); ?>">
       </div>
       <div class="col-lg-7">
         <?php     
           the_archive_title( '<h4 class="entry-title">', '</h4>' ); 
           the_archive_description( '<div class="entry-description mt-2">', '</div>' ); 
           if(get_the_author_meta( 'user_url', $author_id ) !== '') {
            $author_website = get_the_author_meta( 'user_url', $author_id );
            echo sprintf( 
            '<div class="mt-3"> %1$s <a href="%2$s" target="_blank">%3$s</a></div>',
              esc_html('Website: ', 'sarmaya'),
              esc_url($author_website),
              esc_html(preg_replace("#^http(s)?://#","",$author_website))
            );
          }
         ?>
       </div>
     </div>
   </div>
 </div>
 
<?php } else { ?>

<div class="page-main-title">
  <div class="container">
    <div class="row align-items-center">
      <div class="col-lg-8">
        <?php     
          the_archive_title( '<h1 class="entry-title h2 mb-0">', '</h1>' ); 
          the_archive_description( '<div class="entry-description mt-2">', '</div>' );   
        ?>
      </div>
    </div>
  </div>
</div>

<?php }

$container = ( false === get_theme_mod('sarmaya_is_blog_page_fluid', sarmaya_defaults( 'is_blog_page_fluid' ) ) ) ? 'container' : 'container-fluid';

$page_layout = get_theme_mod('sarmaya_blog_page_layout', sarmaya_defaults( 'blog_page_layout' ) );

if ($page_layout == '' && !is_active_sidebar( 'sidebar-1' )) {
	$page_layout = 'full_width';
} elseif ($page_layout == '' && is_active_sidebar( 'sidebar-1' )) {
	$page_layout = 'right_sidebar';
}

$page_col_size = $page_layout == 'full_width' ? 'col-lg-12' : 'col-lg-8';
$page_sidebar_align = $page_layout == 'left_sidebar' ? ' order-lg-2' : '';

$items_col_size = get_theme_mod( 'sarmaya_blog_post_layout_col', sarmaya_defaults( 'blog_post_layout_col' ));

if ($items_col_size == '' && $page_col_size == 'col-lg-12') {
	$items_col_size = 'col-lg-4';
} elseif($items_col_size == '' && $page_col_size !== 'col-lg-12') {
	$items_col_size = 'col-lg-6';
}

?>
<div class="<?php echo esc_attr($container); ?> mt-7">

	<div class="row large-gutters">

		<div class="<?php echo esc_attr($page_col_size); echo esc_attr($page_sidebar_align);?> mb-7">

			<div class="blog-post row large-gutters masonry-grid <?php echo esc_attr(get_theme_mod( 'sarmaya_post_style', 'stander-post-style' )); ?>">
		
			<?php
		
			if ( have_posts() ) :
			
			
				/* Start the Loop */
				while ( have_posts() ) :
				
					the_post();
				
					?>
					<div class="<?php echo esc_attr($items_col_size); ?>">
					<?php
		
					/*
					 * Include the Post-Format-specific template for the content.
					 * If you want to override this in a child theme, then include a file
					 * called content-___.php (where ___ is the Post Format name) and that will be used instead.
					 */
					get_template_part( 'template-parts/post/content', get_post_format() );
				
					?>
					</div>
					<?php
		
				endwhile;
			
				if ( ! class_exists( 'Jetpack' ) || ! Jetpack::is_module_active( 'infinite-scroll' ) ) :
					/*
					 * The posts pagination outputs a set of page numbers with links to the previous and next pages of posts.
					 *
					 * @link https://codex.wordpress.org/Function_Reference/the_posts_pagination
					 */
					the_posts_pagination(
						array(
							'mid_size' => 2,
						)
					);
				endif;
			
			else :
			
				get_template_part( 'template-parts/post/content', 'none' );
			
			endif; ?>
		
			</div>

		</div>
		
		<?php

		if ( is_active_sidebar( 'sidebar-1' ) && $page_layout !== 'full_width' ) : ?>

		<div class="col-lg-4 mb-7">

			<aside class="widget-area" role="complementary" aria-label="<?php esc_attr_e( 'Footer', 'sarmaya' ); ?>">
				
				<?php
				
				if ( is_active_sidebar( 'sidebar-1' ) ) {
					dynamic_sidebar( 'sidebar-1' ); 
				}

				?>

			</aside>
			<!-- .widget-area -->
			
		</div>

		<?php endif; ?>
		

	</div>

</div>

<?php
get_footer();
