<?php
/**
 * Theme backwards compatibility functionality
 *
 * Prevents Sarmaya from running on WordPress versions prior to 4.7,
 * since this theme is not meant to be backward compatible beyond that and
 * relies on many newer functions and markup changes introduced in 4.7.
 *
 * @package     Sarmaya
 * @author      Amjad Ali
 * @license     http://www.gnu.org/licenses/gpl-3.0.html GNU Public License
 */

/**
 * Prevent switching to Sarmaya on old versions of WordPress.
 *
 * Switches to the default theme.
 */
function sarmaya_switch_theme() {
	switch_theme( WP_DEFAULT_THEME, WP_DEFAULT_THEME );
	unset( $_GET['activated'] );
	add_action( 'admin_notices', 'sarmaya_upgrade_notice' );
}
add_action( 'after_switch_theme', 'sarmaya_switch_theme' );

/**
 * Add message for unsuccessful theme switch.
 *
 * Prints an update nag after an unsuccessful attempt to switch to
 * this theme on WordPress versions prior to 4.7.
 */
function sarmaya_upgrade_notice() {
	/* translators: WordPress version */
	$message = sprintf( esc_html__( 'Sarmaya requires at least WordPress version 4.7. You are running version %s. Please upgrade and try again.', 'sarmaya' ), $GLOBALS['wp_version'] );
	printf( '<div class="error"><p>%s</p></div>', esc_html( $message ) );
}

/**
 * Prevent the Customizer from being loaded on WordPress versions prior to 4.7.
 */
function sarmaya_customize() {
	wp_die(
		/* translators: WordPress version */
		sprintf( esc_html__( 'Sarmaya requires at least WordPress version 4.7. You are running version %s. Please upgrade and try again.', 'sarmaya' ), esc_html( $GLOBALS['wp_version'] ) ), '', array(
			'back_link' => true,
		)
	);
}
add_action( 'load-customize.php', 'sarmaya_customize' );

/**
 * Prevent the Theme Preview from being loaded on WordPress versions prior to 4.7.
 */
function sarmaya_preview() {
	if ( isset( $_GET['preview'] ) ) {
		/* translators: WordPress version */
		wp_die( sprintf( esc_html__( 'Sarmaya requires at least WordPress version 4.7. You are running version %s. Please upgrade and try again.', 'sarmaya' ), esc_html( $GLOBALS['wp_version'] ) ) );
	}
}
add_action( 'template_redirect', 'sarmaya_preview' );
