<?php
/**
 * Sarmaya Customizer Class
 *
 * @package  sarmaya
 * @since    1.0.0
 */

if (!defined('ABSPATH')) {
    exit;
}

if (!class_exists('Sarmaya_Customizer')):

    /**
     * The Sarmaya Customizer class
     */
    class Sarmaya_Customizer {

        /**
         * Setup class.
         *
         * @since 1.0
         */
        public function __construct() {
            add_action('customize_register', array($this, 'customize_register'), 10);
            add_action('wp_enqueue_scripts', array($this, 'add_customizer_css'), 140);
            add_action('enqueue_block_editor_assets', array($this, 'block_editor_customizer_css'));
        }

        /**
         * Add postMessage support for site title and description for the Theme Customizer along with several other settings.
         *
         * @param WP_Customize_Manager $wp_customize Theme Customizer object.
         * @since  1.0.0
         */
        public function customize_register($wp_customize) {

            // Move background color setting alongside background image.
            $wp_customize->get_control('background_color')->section  = 'background_image';
            $wp_customize->get_control('background_color')->priority = 20;

            // Change background image section title & priority.
            $wp_customize->get_section('background_image')->title    = __('Background', 'sarmaya');
            $wp_customize->get_section('background_image')->priority = 30;

            // Change header image section title & priority.
            $wp_customize->get_section('header_image')->title    = __('Header', 'sarmaya');
            $wp_customize->get_section('header_image')->priority = 25;

            /**
             * Add custom controls.
             */
            require get_parent_theme_file_path('inc/customizer/customizer-controls/radio-image/class-etcode-control-radio-image.php');
            require get_parent_theme_file_path('inc/customizer/customizer-controls/range/class-etcode-control-range.php');
            require get_parent_theme_file_path('inc/customizer/customizer-controls/toggle/class-etcode-control-toggle.php');
            require get_parent_theme_file_path('inc/customizer/customizer-controls/google-font/class-control-google-font.php');
            /**
             * Register custom controls.
             */
            $wp_customize->register_control_type('ETCode_Radio_Image_Control');
            $wp_customize->register_section_type('ETCode_Range_Control');
            $wp_customize->register_section_type('ETCode_Toggle_Control');

            /*******************************************
            Header
             ********************************************/

            $wp_customize->add_section('sarmaya_header', array(
                'priority'   => 10,
                'capability' => 'edit_theme_options',
                'title'      => esc_html__('Header', 'sarmaya'),
            ));

            // Header Background Color

            $wp_customize->add_setting('sarmaya_header_bg_color', array(
                'default'           => sarmaya_defaults('header_bg_color'),
                'sanitize_callback' => 'sanitize_hex_color',
            ));
            $wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'sarmaya_header_bg_color', array(
                'label'    => esc_html__('Header Background Color', 'sarmaya'),
                'section'  => 'sarmaya_header',
                'settings' => 'sarmaya_header_bg_color',
            )));

            // Header Full Width toggle
            $wp_customize->add_setting('sarmaya_is_header_fluid', array(
                'default'           => sarmaya_defaults('is_header_fluid'),
                'sanitize_callback' => 'sarmaya_sanitize_checkbox',
            ));
            $wp_customize->add_control(new ETCode_Toggle_Control($wp_customize, 'sarmaya_is_header_fluid', array(
                'label'    => esc_html__('Header Full Width', 'sarmaya'),
                'section'  => 'sarmaya_header',
                'settings' => 'sarmaya_is_header_fluid',
                'type'     => 'toggle',
            )));

            // Fixed top Header

            $wp_customize->add_setting('sarmaya_is_fixed_top_navbar', array(
                'default'           => sarmaya_defaults('is_fixed_top_navbar'),
                'sanitize_callback' => 'sarmaya_sanitize_checkbox',
            ));
            $wp_customize->add_control(new ETCode_Toggle_Control($wp_customize, 'sarmaya_is_fixed_top_navbar', array(
                'label'    => esc_html__('Header fixed top (Sticky top)', 'sarmaya'),
                'section'  => 'sarmaya_header',
                'settings' => 'sarmaya_is_fixed_top_navbar',
                'type'     => 'toggle',
            )));

            // Navbar search form

            $wp_customize->add_setting('sarmaya_is_navbar_search_form', array(
                'default'           => sarmaya_defaults('is_navbar_search_form'),
                'sanitize_callback' => 'sarmaya_sanitize_checkbox',
            ));
            $wp_customize->add_control(new ETCode_Toggle_Control($wp_customize, 'sarmaya_is_navbar_search_form', array(
                'label'    => esc_html__('Navbar search form', 'sarmaya'),
                'section'  => 'sarmaya_header',
                'settings' => 'sarmaya_is_navbar_search_form',
                'type'     => 'toggle',
            )));

            // Navbar Social nav

            $wp_customize->add_setting('sarmaya_is_navbar_social_nav', array(
                'default'           => sarmaya_defaults('is_navbar_social_nav'),
                'sanitize_callback' => 'sarmaya_sanitize_checkbox',
            ));
            $wp_customize->add_control(new ETCode_Toggle_Control($wp_customize, 'sarmaya_is_navbar_social_nav', array(
                'label'    => esc_html__('Social Icons in navbar', 'sarmaya'),
                'section'  => 'sarmaya_header',
                'settings' => 'sarmaya_is_navbar_social_nav',
                'type'     => 'toggle',
            )));

            // Shopping cart in navbar

            $wp_customize->add_setting('sarmaya_is_navbar_shopping_cart', array(
                'default'           => sarmaya_defaults('is_navbar_shopping_cart'),
                'sanitize_callback' => 'sarmaya_sanitize_checkbox',
            ));
            $wp_customize->add_control(new ETCode_Toggle_Control($wp_customize, 'sarmaya_is_navbar_shopping_cart', array(
                'label'    => esc_html__('Shopping cart in navbar', 'sarmaya'),
                'section'  => 'sarmaya_header',
                'settings' => 'sarmaya_is_navbar_shopping_cart',
                'type'     => 'toggle',
            )));

            // My Account link in navbar
            $wp_customize->add_setting('sarmaya_is_navbar_my_account', array(
                'default'           => sarmaya_defaults('is_navbar_my_account'),
                'sanitize_callback' => 'sarmaya_sanitize_checkbox',
            ));
            $wp_customize->add_control(new ETCode_Toggle_Control($wp_customize, 'sarmaya_is_navbar_my_account', array(
                'label'    => esc_html__('My Account link in navbar', 'sarmaya'),
                'section'  => 'sarmaya_header',
                'settings' => 'sarmaya_is_navbar_my_account',
                'type'     => 'toggle',
            )));

            /*******************************************
            Site Identity
             ********************************************/

            // Max Width

            $wp_customize->add_setting('sarmaya_logo_max_width', array(
                'default'           => sarmaya_defaults('logo_max_width'),
                'sanitize_callback' => 'absint',
            ));
            $wp_customize->add_control(new ETCode_Range_Control($wp_customize, 'sarmaya_logo_max_width', array(
                'type'        => 'etcode-range',
                'label'       => esc_html__('Logo Max Width', 'sarmaya'),
                'settings'    => 'sarmaya_logo_max_width',
                'section'     => 'title_tagline',
                'description' => 'px',
                'default'     => sarmaya_defaults('logo_max_width'),
                'priority'    => 8,
                'input_attrs' => array(
                    'min'  => 0,
                    'max'  => 300,
                    'step' => 1,
                ),
            )));

            // Header tagline on off

            $wp_customize->add_setting('sarmaya_is_header_tagline', array(
                'default'           => false,
                'sanitize_callback' => 'sarmaya_sanitize_checkbox',
            ));
            $wp_customize->add_control(new ETCode_Toggle_Control($wp_customize, 'sarmaya_is_header_tagline', array(
                'label'       => esc_html__('Tagline?', 'sarmaya'),
                'description' => esc_html__('Enable or disable Header Tagline.', 'sarmaya'),
                'section'     => 'title_tagline',
                'priority'    => 11,
                'settings'    => 'sarmaya_is_header_tagline',
                'type'        => 'toggle',
            )));

            // Light logo

            $wp_customize->add_setting('sarmaya_logo_light', array(
                'sanitize_callback' => 'sanitize_text_field',
            ));
            $wp_customize->add_control(new WP_Customize_Media_Control($wp_customize, 'sarmaya_logo_light', array(
                'label'    => esc_html__('Logo - Light', 'sarmaya'),
                'section'  => 'title_tagline',
                'settings' => 'sarmaya_logo_light',
                'priority' => 40,
            )));

            /*******************************************
            Typography
             ********************************************/
            $wp_customize->add_panel('sarmaya_typography', array(
                'priority'   => 21,
                'capability' => 'edit_theme_options',
                'title'      => esc_html__('Typography', 'sarmaya'),
            ));
            /***** Add the Headings Typography section *****/
            $wp_customize->add_section('sarmaya_headings', array(
                'title' => esc_html__('Headings', 'sarmaya'),
                'panel' => 'sarmaya_typography',
            ));

            // Headings Font Family

            $wp_customize->add_setting('sarmaya_headings_font', array(
                'default'           => sarmaya_defaults('headings_font'),
                'sanitize_callback' => 'sanitize_text_field',
            ));
            $wp_customize->add_control(new Google_Font_Dropdown_Custom_Control($wp_customize, 'sarmaya_headings_font', array(
                'label'    => 'Font Family',
                'section'  => 'sarmaya_headings',
                'settings' => 'sarmaya_headings_font',
            )));

            // Headings Font weight

            $wp_customize->add_setting('sarmaya_headings_font_weight', array(
                'sanitize_callback' => 'sanitize_key',
            ));
            $wp_customize->add_control('sarmaya_headings_font_weight', array(
                'label'       => esc_html__('Font Weight', 'sarmaya'),
                'description' => esc_html__('Important: Not all fonts support every font-weight.', 'sarmaya'),
                'section'     => 'sarmaya_headings',
                'settings'    => 'sarmaya_headings_font_weight',
                'type'        => 'select',
                'choices'     => array(
                    ''    => esc_html__('Default', 'sarmaya'),
                    '100' => esc_html__('Extra Light: 100', 'sarmaya'),
                    '200' => esc_html__('Light: 200', 'sarmaya'),
                    '300' => esc_html__('Book: 300', 'sarmaya'),
                    '400' => esc_html__('Normal: 400', 'sarmaya'),
                    '600' => esc_html__('Semibold: 600', 'sarmaya'),
                    '700' => esc_html__('Bold: 700', 'sarmaya'),
                    '800' => esc_html__('Extra Bold: 800', 'sarmaya'),
                ),
            ));

            // Headings Font Style

            $wp_customize->add_setting('sarmaya_headings_font_style', array(
                'sanitize_callback' => 'sanitize_key',
            ));
            $wp_customize->add_control('sarmaya_headings_font_style', array(
                'label'    => esc_html__('Font Style', 'sarmaya'),
                'section'  => 'sarmaya_headings',
                'settings' => 'sarmaya_headings_font_style',
                'type'     => 'select',
                'choices'  => array(
                    ''       => esc_html__('Default', 'sarmaya'),
                    'normal' => esc_html__('Normal', 'sarmaya'),
                    'italic' => esc_html__('Italic', 'sarmaya'),
                ),
            ));

            // Headings Font Color

            $wp_customize->add_setting('sarmaya_headings_font_color', array(
                'sanitize_callback' => 'sanitize_hex_color',
            ));
            $wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'sarmaya_headings_font_color', array(
                'label'    => esc_html__('Font Color', 'sarmaya'),
                'section'  => 'sarmaya_headings',
                'settings' => 'sarmaya_headings_font_color',
            )));
            /***** Add the Body Typography section *****/
            $wp_customize->add_section('sarmaya_body', array(
                'title' => esc_html__('Body', 'sarmaya'),
                'panel' => 'sarmaya_typography',
            ));

            // Body Font Family

            $wp_customize->add_setting('sarmaya_body_font', array(
                'default'           => sarmaya_defaults('body_font'),
                'sanitize_callback' => 'sanitize_text_field',
            ));
            $wp_customize->add_control(new Google_Font_Dropdown_Custom_Control($wp_customize, 'sarmaya_body_font', array(
                'label'    => 'Font Family',
                'section'  => 'sarmaya_body',
                'settings' => 'sarmaya_body_font',
            )));

            // Body Font weight

            $wp_customize->add_setting('sarmaya_body_font_weight', array(
                'sanitize_callback' => 'sanitize_key',
            ));
            $wp_customize->add_control('sarmaya_body_font_weight', array(
                'label'       => esc_html__('Font Weight', 'sarmaya'),
                'description' => esc_html__('Important: Not all fonts support every font-weight.', 'sarmaya'),
                'section'     => 'sarmaya_body',
                'settings'    => 'sarmaya_body_font_weight',
                'type'        => 'select',
                'choices'     => array(
                    ''    => esc_html__('Default', 'sarmaya'),
                    '100' => esc_html__('Extra Light: 100', 'sarmaya'),
                    '200' => esc_html__('Light: 200', 'sarmaya'),
                    '300' => esc_html__('Book: 300', 'sarmaya'),
                    '400' => esc_html__('Normal: 400', 'sarmaya'),
                    '600' => esc_html__('Semibold: 600', 'sarmaya'),
                    '700' => esc_html__('Bold: 700', 'sarmaya'),
                    '800' => esc_html__('Extra Bold: 800', 'sarmaya'),
                ),
            ));

            // Body Font Style

            $wp_customize->add_setting('sarmaya_body_font_style', array(
                'sanitize_callback' => 'sanitize_key',
            ));
            $wp_customize->add_control('sarmaya_body_font_style', array(
                'label'    => esc_html__('Font Style', 'sarmaya'),
                'section'  => 'sarmaya_body',
                'settings' => 'sarmaya_body_font_style',
                'type'     => 'select',
                'choices'  => array(
                    ''       => esc_html__('Default', 'sarmaya'),
                    'normal' => esc_html__('Normal', 'sarmaya'),
                    'italic' => esc_html__('Italic', 'sarmaya'),
                ),
            ));

            // Body Font size

            $wp_customize->add_setting('sarmaya_body_font_size', array(
                'default'           => sarmaya_defaults('body_font_size'),
                'sanitize_callback' => 'absint',
            ));
            $wp_customize->add_control(new ETCode_Range_Control($wp_customize, 'sarmaya_body_font_size', array(
                'type'        => 'etcode-range',
                'label'       => esc_html__('Font Size', 'sarmaya'),
                'section'     => 'sarmaya_body',
                'settings'    => 'sarmaya_body_font_size',
                'default'     => sarmaya_defaults('body_font_size'),
                'description' => 'px',
                'input_attrs' => array(
                    'min'  => 0,
                    'max'  => 32,
                    'step' => 1,
                ),
            )));

            // Body Font Color

            $wp_customize->add_setting('sarmaya_body_font_color', array(
                'sanitize_callback' => 'sanitize_hex_color',
            ));
            $wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'sarmaya_body_font_color', array(
                'label'    => esc_html__('Font Color', 'sarmaya'),
                'section'  => 'sarmaya_body',
                'settings' => 'sarmaya_body_font_color',
            )));

            // Body Link Color

            $wp_customize->add_setting('sarmaya_body_font_link_color', array(
                'sanitize_callback' => 'sanitize_hex_color',
            ));
            $wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'sarmaya_body_font_link_color', array(
                'label'    => esc_html__('Link Color', 'sarmaya'),
                'section'  => 'sarmaya_body',
                'settings' => 'sarmaya_body_font_link_color',
            )));

            /***** Add the Menu Typography section *****/

            $wp_customize->add_section('sarmaya_menu', array(
                'title' => esc_html__('Menu', 'sarmaya'),
                'panel' => 'sarmaya_typography',
            ));

            // Menu Font size

            $wp_customize->add_setting('sarmaya_menu_font_size', array(
                'default'           => sarmaya_defaults('menu_font_size'),
                'sanitize_callback' => 'absint',
            ));
            $wp_customize->add_control(new ETCode_Range_Control($wp_customize, 'sarmaya_menu_font_size', array(
                'type'        => 'etcode-range',
                'label'       => esc_html__('Font Size', 'sarmaya'),
                'section'     => 'sarmaya_menu',
                'settings'    => 'sarmaya_menu_font_size',
                'default'     => sarmaya_defaults('menu_font_size'),
                'description' => 'px',
                'input_attrs' => array(
                    'min'  => 0,
                    'max'  => 32,
                    'step' => 1,
                ),
            )));

            // Menu Font Color

            $wp_customize->add_setting('sarmaya_menu_font_color', array(
                'sanitize_callback' => 'sanitize_hex_color',
            ));
            $wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'sarmaya_menu_font_color', array(
                'label'    => esc_html__('Font Color', 'sarmaya'),
                'section'  => 'sarmaya_menu',
                'settings' => 'sarmaya_menu_font_color',
            )));

            // Menu Font Hover and active Color

            $wp_customize->add_setting('sarmaya_menu_font_hover_active_color', array(
                'sanitize_callback' => 'sanitize_hex_color',
            ));
            $wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'sarmaya_menu_font_hover_active_color', array(
                'label'    => esc_html__('Font Hover and Active Color', 'sarmaya'),
                'section'  => 'sarmaya_menu',
                'settings' => 'sarmaya_menu_font_hover_active_color',
            )));

            /*******************************************
            Colors
             ********************************************/

            // Accent color
            $wp_customize->add_setting('sarmaya_accent_color', array(
                'sanitize_callback' => 'sanitize_hex_color',
            ));
            $wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'sarmaya_accent_color', array(
                'label'       => esc_html__('Accent color', 'sarmaya'),
                'description' => esc_html__('Choose the most dominant theme color.', 'sarmaya'),
                'section'     => 'colors',
                'settings'    => 'sarmaya_accent_color',
            )));

            // Accent Background color
            $wp_customize->add_setting('sarmaya_accent_bg_color', array(
                'sanitize_callback' => 'sanitize_hex_color',
            ));
            $wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'sarmaya_accent_bg_color', array(
                'label'       => esc_html__('Accent background color', 'sarmaya'),
                'description' => esc_html__('Choose the accent background color.', 'sarmaya'),
                'section'     => 'colors',
                'settings'    => 'sarmaya_accent_bg_color',
            )));

            // Button Text Color

            $wp_customize->add_setting('sarmaya_btn_text_color', array(
                'sanitize_callback' => 'sanitize_hex_color',
            ));
            $wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'sarmaya_btn_text_color', array(
                'label'    => esc_html__('Button text color', 'sarmaya'),
                'section'  => 'colors',
                'settings' => 'sarmaya_btn_text_color',
            )));

            // Button Text Hover Color

            $wp_customize->add_setting('sarmaya_btn_text_hover_color', array(
                'sanitize_callback' => 'sanitize_hex_color',
            ));
            $wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'sarmaya_btn_text_hover_color', array(
                'label'    => esc_html__('Button text hover color', 'sarmaya'),
                'section'  => 'colors',
                'settings' => 'sarmaya_btn_text_hover_color',
            )));

            // Button background Color

            $wp_customize->add_setting('sarmaya_btn_background_color', array(
                'sanitize_callback' => 'sanitize_hex_color',
            ));
            $wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'sarmaya_btn_background_color', array(
                'label'    => esc_html__('Button background color', 'sarmaya'),
                'section'  => 'colors',
                'settings' => 'sarmaya_btn_background_color',
            )));

            // Button background Hover Color

            $wp_customize->add_setting('sarmaya_btn_background_hover_color', array(
                'sanitize_callback' => 'sanitize_hex_color',
            ));
            $wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'sarmaya_btn_background_hover_color', array(
                'label'    => esc_html__('Button background hover color', 'sarmaya'),
                'section'  => 'colors',
                'settings' => 'sarmaya_btn_background_hover_color',
            )));

            /*******************************************
            Blog panel
             ********************************************/
            $wp_customize->add_panel('sarmaya_blog', array(
                'capability' => 'edit_theme_options',
                'title'      => esc_html__('Blog', 'sarmaya'),
            ));
            /***** Add the Posts section *****/
            $wp_customize->add_section('sarmaya_posts', array(
                'title' => esc_html__('General Posts', 'sarmaya'),
                'panel' => 'sarmaya_blog',
            ));

            // Add the Blog page width

            $wp_customize->add_setting('sarmaya_is_blog_page_fluid', array(
                'default'           => sarmaya_defaults('is_blog_page_fluid'),
                'sanitize_callback' => 'sarmaya_sanitize_checkbox',
            ));
            $wp_customize->add_control(new ETCode_Toggle_Control($wp_customize, 'sarmaya_is_blog_page_fluid', array(
                'label'    => esc_html__('Blog Full Width', 'sarmaya'),
                'section'  => 'sarmaya_posts',
                'settings' => 'sarmaya_is_blog_page_fluid',
                'type'     => 'toggle',
            )));

            // Add the Blog page layout setting and control.
            $wp_customize->add_setting('sarmaya_blog_page_layout', array(
                'default'           => sarmaya_defaults('blog_page_layout'),
                'sanitize_callback' => 'sanitize_key',
            ));
            $wp_customize->add_control(new ETCode_Radio_Image_Control($wp_customize, 'sarmaya_blog_page_layout', array(
                'label'       => esc_html__('Blog page layout', 'sarmaya'),
                'description' => esc_html__('Select the Blog and Archives page layout.', 'sarmaya'),
                'section'     => 'sarmaya_posts',
                'settings'    => 'sarmaya_blog_page_layout',
                'choices'     => array(
                    'left_sidebar'  => array(
                        'label' => esc_html__('Left sidebar', 'sarmaya'),
                        'url'   => '%s/assets/images/admin/left-sidebar.jpg',
                    ),
                    'full_width'    => array(
                        'label' => esc_html__('Full width', 'sarmaya'),
                        'url'   => '%s/assets/images/admin/full-width.jpg',
                    ),
                    'right_sidebar' => array(
                        'label' => esc_html__('Right sidebar', 'sarmaya'),
                        'url'   => '%s/assets/images/admin/right-sidebar.jpg',
                    ),
                ),
            )));

            // Add the Blog Style setting and control.

            $wp_customize->add_setting('sarmaya_post_style', array(
                'default'           => sarmaya_defaults('post_style'),
                'sanitize_callback' => 'sanitize_key',
            ));
            $wp_customize->add_control(new ETCode_Radio_Image_Control($wp_customize, 'sarmaya_post_style', array(
                'label'       => esc_html__('Blog Style', 'sarmaya'),
                'description' => esc_html__('Select the blog display style.', 'sarmaya'),
                'section'     => 'sarmaya_posts',
                'settings'    => 'sarmaya_post_style',
                'choices'     => array(
                    'stander-post-style' => array(
                        'label' => esc_html__('Stander blog', 'sarmaya'),
                        'url'   => '%s/assets/images/admin/post-style1.jpg',
                    ),
                    'card-post-style'    => array(
                        'label' => esc_html__('Card blog', 'sarmaya'),
                        'url'   => '%s/assets/images/admin/post-style2.jpg',
                    ),
                    'blog-img-overlay'   => array(
                        'label' => esc_html__('Blog Image overlay', 'sarmaya'),
                        'url'   => '%s/assets/images/admin/post-style3.jpg',
                    ),
                ),
            )));

            // Add the Blog posts layout Columns setting and control.

            $wp_customize->add_setting('sarmaya_blog_post_layout_col', array(
                'default'           => sarmaya_defaults('blog_post_layout_col'),
                'sanitize_callback' => 'sanitize_key',
            ));
            $wp_customize->add_control('sarmaya_blog_post_layout_col', array(
                'label'    => esc_html__('Posts Columns', 'sarmaya'),
                'section'  => 'sarmaya_posts',
                'settings' => 'sarmaya_blog_post_layout_col',
                'type'     => 'radio',
                'choices'  => array(
                    'col-lg-12' => esc_html__('1 columns', 'sarmaya'),
                    'col-lg-6'  => esc_html__('2 columns', 'sarmaya'),
                    'col-lg-4'  => esc_html__('3 columns', 'sarmaya'),
                    'col-lg-3'  => esc_html__('4 columns', 'sarmaya'),
                ),
            ));

            // Add the blog post Featured Image button setting and control.
            $wp_customize->add_setting('sarmaya_is_blog_post_featured_image', array(
                'default'           => sarmaya_defaults('is_blog_post_featured_image'),
                'sanitize_callback' => 'sarmaya_sanitize_checkbox',
            ));
            $wp_customize->add_control(new ETCode_Toggle_Control($wp_customize, 'sarmaya_is_blog_post_featured_image', array(
                'label'       => esc_html__('Featured Image', 'sarmaya'),
                'description' => esc_html__('Enable or disable Featured Image that display in the blog.', 'sarmaya'),
                'section'     => 'sarmaya_posts',
                'settings'    => 'sarmaya_is_blog_post_featured_image',
                'type'        => 'toggle',
            )));

            // Add the Blog posts image size setting and control.
            $wp_customize->add_setting('sarmaya_blog_posts_featured_image_size', array(
                'default'           => sarmaya_defaults('blog_posts_featured_image_size'),
                'sanitize_callback' => 'sanitize_key',
            ));
            $wp_customize->add_control('sarmaya_blog_posts_featured_image_size', array(
                'label'    => esc_html__('Select Featured Image Size', 'sarmaya'),
                'section'  => 'sarmaya_posts',
                'settings' => 'sarmaya_blog_posts_featured_image_size',
                'type'     => 'select',
                'choices'  => sarmaya_get_image_sizes(),
            ));

            // Add the Blog Post Excerpt button setting and control.

            $wp_customize->add_setting('sarmaya_is_blog_post_content', array(
                'default'           => sarmaya_defaults('is_blog_post_content'),
                'sanitize_callback' => 'sarmaya_sanitize_checkbox',
            ));
            $wp_customize->add_control(new ETCode_Toggle_Control($wp_customize, 'sarmaya_is_blog_post_content', array(
                'label'       => esc_html__('Post Content', 'sarmaya'),
                'description' => esc_html__('Enable or disable Post content that display in the blog.', 'sarmaya'),
                'section'     => 'sarmaya_posts',
                'settings'    => 'sarmaya_is_blog_post_content',
                'type'        => 'toggle',
            )));

            $wp_customize->add_setting('sarmaya_is_blog_post_excerpt', array(
                'default'           => sarmaya_defaults('is_blog_post_excerpt'),
                'sanitize_callback' => 'sarmaya_sanitize_checkbox',
            ));
            $wp_customize->add_control(new ETCode_Toggle_Control($wp_customize, 'sarmaya_is_blog_post_excerpt', array(
                'label'       => esc_html__('Display Post Excerpt', 'sarmaya'),
                'description' => esc_html__('Enable to display only post excerpt inside full content.', 'sarmaya'),
                'section'     => 'sarmaya_posts',
                'settings'    => 'sarmaya_is_blog_post_excerpt',
                'type'        => 'toggle',
            )));

            // Blog post excerpt length
            $wp_customize->add_setting('sarmaya_blog_post_excerpt_length', array(
                'default'           => sarmaya_defaults('blog_post_excerpt_length'),
                'sanitize_callback' => 'absint',
            ));
            $wp_customize->add_control(new ETCode_Range_Control($wp_customize, 'sarmaya_blog_post_excerpt_length', array(
                'type'        => 'etcode-range',
                'label'       => esc_html__('Excerpt length', 'sarmaya'),
                'section'     => 'sarmaya_posts',
                'settings'    => 'sarmaya_blog_post_excerpt_length',
                'default'     => 25,
                'input_attrs' => array(
                    'min'  => 0,
                    'step' => 1,
                ),
            )));

            // Add the Blog Post Categories setting and control.

            $wp_customize->add_setting('sarmaya_is_blog_post_categories', array(
                'default'           => sarmaya_defaults('is_blog_post_categories'),
                'sanitize_callback' => 'sarmaya_sanitize_checkbox',
            ));
            $wp_customize->add_control(new ETCode_Toggle_Control($wp_customize, 'sarmaya_is_blog_post_categories', array(
                'label'       => esc_html__('Categories', 'sarmaya'),
                'description' => esc_html__('Enable or disable categories that display in the post metadata.', 'sarmaya'),
                'section'     => 'sarmaya_posts',
                'settings'    => 'sarmaya_is_blog_post_categories',
                'type'        => 'toggle',
            )));

            // Add the Blog Post edit btn setting and control.

            $wp_customize->add_setting('sarmaya_is_blog_post_edit_btn', array(
                'default'           => sarmaya_defaults('is_blog_post_edit_btn'),
                'sanitize_callback' => 'sarmaya_sanitize_checkbox',
            ));
            $wp_customize->add_control(new ETCode_Toggle_Control($wp_customize, 'sarmaya_is_blog_post_edit_btn', array(
                'label'       => esc_html__('Categories', 'sarmaya'),
                'description' => esc_html__('Enable or disable categories that display in the post metadata.', 'sarmaya'),
                'section'     => 'sarmaya_posts',
                'settings'    => 'sarmaya_is_blog_post_edit_btn',
                'type'        => 'toggle',
            )));

            // Add the Blog Post Author setting and control.

            $wp_customize->add_setting('sarmaya_is_blog_post_author', array(
                'default'           => sarmaya_defaults('is_blog_post_author'),
                'sanitize_callback' => 'sarmaya_sanitize_checkbox',
            ));
            $wp_customize->add_control(new ETCode_Toggle_Control($wp_customize, 'sarmaya_is_blog_post_author', array(
                'label'       => esc_html__('Author', 'sarmaya'),
                'description' => esc_html__('Add the post author metadata.', 'sarmaya'),
                'section'     => 'sarmaya_posts',
                'settings'    => 'sarmaya_is_blog_post_author',
                'type'        => 'toggle',
            )));

            // Add the Blog Post Date setting and control.

            $wp_customize->add_setting('sarmaya_is_blog_post_date', array(
                'default'           => sarmaya_defaults('is_blog_post_date'),
                'sanitize_callback' => 'sarmaya_sanitize_checkbox',
            ));
            $wp_customize->add_control(new ETCode_Toggle_Control($wp_customize, 'sarmaya_is_blog_post_date', array(
                'label'       => esc_html__('Post Date metadata', 'sarmaya'),
                'description' => esc_html__('Enable or disable Post Date that display in the post metadata.', 'sarmaya'),
                'section'     => 'sarmaya_posts',
                'settings'    => 'sarmaya_is_blog_post_date',
                'type'        => 'toggle',
            )));

            // Add the Blog Post Comments Counter setting and control.

            $wp_customize->add_setting('sarmaya_is_blog_post_comments_counter', array(
                'default'           => sarmaya_defaults('is_blog_post_comments_counter'),
                'sanitize_callback' => 'sarmaya_sanitize_checkbox',
            ));
            $wp_customize->add_control(new ETCode_Toggle_Control($wp_customize, 'sarmaya_blog_post_comments_counter', array(
                'label'       => esc_html__('Comments Counter metadata', 'sarmaya'),
                'description' => esc_html__('Enable or disable comments counter that display in the post metadata.', 'sarmaya'),
                'section'     => 'sarmaya_posts',
                'settings'    => 'sarmaya_blog_post_comments_counter',
                'type'        => 'toggle',
            )));

            // Add the Blog Post Tags setting and control.

            $wp_customize->add_setting('sarmaya_is_blog_post_tags', array(
                'default'           => sarmaya_defaults('is_blog_post_tags'),
                'sanitize_callback' => 'sarmaya_sanitize_checkbox',
            ));
            $wp_customize->add_control(new ETCode_Toggle_Control($wp_customize, 'sarmaya_is_blog_post_tags', array(
                'label'       => esc_html__('Tags metadata', 'sarmaya'),
                'description' => esc_html__('Enable or disable Tags that display in the post metadata.', 'sarmaya'),
                'section'     => 'sarmaya_posts',
                'settings'    => 'sarmaya_is_blog_post_tags',
                'type'        => 'toggle',
            )));

            // Add the Blog Post Read more button setting and control.

            $wp_customize->add_setting('sarmaya_is_blog_post_read_more_btn', array(
                'default'           => sarmaya_defaults('is_blog_post_read_more_btn'),
                'sanitize_callback' => 'sarmaya_sanitize_checkbox',
            ));
            $wp_customize->add_control(new ETCode_Toggle_Control($wp_customize, 'sarmaya_is_blog_post_read_more_btn', array(
                'label'       => esc_html__('Read More Button', 'sarmaya'),
                'description' => esc_html__('Enable or disable Read More button that display in the blog loop.', 'sarmaya'),
                'section'     => 'sarmaya_posts',
                'settings'    => 'sarmaya_is_blog_post_read_more_btn',
                'type'        => 'toggle',
            )));

            /***** Add the Single Post section *****/

            $wp_customize->add_section('sarmaya_single_post', array(
                'title' => esc_html__('Single Post', 'sarmaya'),
                'panel' => 'sarmaya_blog',
            ));

            // Add the Single Post layout setting and control.

            $wp_customize->add_setting('sarmaya_single_post_page_layout', array(
                'default'           => sarmaya_defaults('single_post_page_layout'),
                'sanitize_callback' => 'sanitize_key',
            ));
            $wp_customize->add_control(new ETCode_Radio_Image_Control($wp_customize, 'sarmaya_single_post_page_layout', array(
                'label'       => esc_html__('Single Post layout', 'sarmaya'),
                'description' => esc_html__('Select the Single Post layout.', 'sarmaya'),
                'section'     => 'sarmaya_single_post',
                'settings'    => 'sarmaya_single_post_page_layout',
                'choices'     => array(
                    'left_sidebar'  => array(
                        'label' => esc_html__('Left sidebar', 'sarmaya'),
                        'url'   => '%s/assets/images/admin/left-sidebar.jpg',
                    ),
                    'full_width'    => array(
                        'label' => esc_html__('Full width', 'sarmaya'),
                        'url'   => '%s/assets/images/admin/full-width.jpg',
                    ),
                    'right_sidebar' => array(
                        'label' => esc_html__('Right sidebar', 'sarmaya'),
                        'url'   => '%s/assets/images/admin/right-sidebar.jpg',
                    ),
                ),
            )));

            // Add the blog post Featured Image button setting and control.
            $wp_customize->add_setting('sarmaya_is_blog_single_post_featured_image', array(
                'default'           => sarmaya_defaults('is_blog_single_post_featured_image'),
                'sanitize_callback' => 'sarmaya_sanitize_checkbox',
            ));
            $wp_customize->add_control(new ETCode_Toggle_Control($wp_customize, 'sarmaya_is_blog_single_post_featured_image', array(
                'label'       => esc_html__('Featured Image', 'sarmaya'),
                'description' => esc_html__('Enable or disable Featured Image that display in the single post.', 'sarmaya'),
                'section'     => 'sarmaya_single_post',
                'settings'    => 'sarmaya_is_blog_single_post_featured_image',
                'type'        => 'toggle',
            )));

            // Add the Blog posts image size setting and control.
            $wp_customize->add_setting('sarmaya_blog_single_post_featured_image_size', array(
                'default'           => sarmaya_defaults('blog_single_post_featured_image_size'),
                'sanitize_callback' => 'sanitize_key',
            ));
            $wp_customize->add_control('sarmaya_blog_single_post_featured_image_size', array(
                'label'    => esc_html__('Select Featured Image Size', 'sarmaya'),
                'section'  => 'sarmaya_single_post',
                'settings' => 'sarmaya_blog_single_post_featured_image_size',
                'type'     => 'select',
                'choices'  => sarmaya_get_image_sizes(),
            ));

            // Add the Single Post Author Box setting and control.

            $wp_customize->add_setting('sarmaya_single_post_author_box', array(
                'default'           => false,
                'sanitize_callback' => 'sarmaya_sanitize_checkbox',
            ));
            $wp_customize->add_control(new ETCode_Toggle_Control($wp_customize, 'sarmaya_single_post_author_box', array(
                'label'       => esc_html__('Author Box', 'sarmaya'),
                'description' => esc_html__('Enable or disable Author Box that display in the single post.', 'sarmaya'),
                'section'     => 'sarmaya_single_post',
                'settings'    => 'sarmaya_single_post_author_box',
                'type'        => 'toggle',
            )));

            // Add the Single Post Post Navigation setting and control.

            $wp_customize->add_setting('sarmaya_single_post_navigation', array(
                'default'           => true,
                'sanitize_callback' => 'sarmaya_sanitize_checkbox',
            ));
            $wp_customize->add_control(new ETCode_Toggle_Control($wp_customize, 'sarmaya_single_post_navigation', array(
                'label'       => esc_html__('Post Navigation', 'sarmaya'),
                'description' => esc_html__('Enable or disable Post Navigation that display in the single post.', 'sarmaya'),
                'section'     => 'sarmaya_single_post',
                'settings'    => 'sarmaya_single_post_navigation',
                'type'        => 'toggle',
            )));

            /*******************************************
            General section
             ********************************************/
            $wp_customize->add_section('sarmaya_general', array(
                'title' => esc_html__('General', 'sarmaya'),

            ));

            // Scroll to Top Button
            $wp_customize->add_setting('sarmaya_is_scroll_to_top_btn', array(
                'default'           => false,
                'sanitize_callback' => 'sarmaya_sanitize_checkbox',
            ));
            $wp_customize->add_control(new ETCode_Toggle_Control($wp_customize, 'sarmaya_is_scroll_to_top_btn', array(
                'label'       => esc_html__('Scroll to Top Button', 'sarmaya'),
                'description' => esc_html__('Enabling this option will display a Back to Top button.', 'sarmaya'),
                'section'     => 'sarmaya_general',
                'settings'    => 'sarmaya_is_scroll_to_top_btn',
                'type'        => 'toggle',
            )));
            // Scroll to Top Button icon color
            $wp_customize->add_setting('sarmaya_scroll_to_top_btn_icon_color', array(
                'sanitize_callback' => 'sanitize_hex_color',
            ));
            $wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'sarmaya_scroll_to_top_btn_icon_color', array(
                'label'    => esc_html__('Button icon color', 'sarmaya'),
                'section'  => 'sarmaya_general',
                'settings' => 'sarmaya_scroll_to_top_btn_icon_color',
            )));
            //  Scroll to Top Button background color
            $wp_customize->add_setting('sarmaya_scroll_to_top_btn_bg_color', array(
                'sanitize_callback' => 'sanitize_hex_color',
            ));
            $wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'sarmaya_scroll_to_top_btn_bg_color', array(
                'label'    => esc_html__('Button Background Color', 'sarmaya'),
                'section'  => 'sarmaya_general',
                'settings' => 'sarmaya_scroll_to_top_btn_bg_color',
            )));

            // Smooth Scroll
            $wp_customize->add_setting('sarmaya_is_smooth_scroll', array(
                'default'           => false,
                'sanitize_callback' => 'sarmaya_sanitize_checkbox',
            ));
            $wp_customize->add_control(new ETCode_Toggle_Control($wp_customize, 'sarmaya_is_smooth_scroll', array(
                'label'       => esc_html__('Smooth Scroll', 'sarmaya'),
                'description' => esc_html__('Enabling this option will activate smooth scrolling.', 'sarmaya'),
                'section'     => 'sarmaya_general',
                'settings'    => 'sarmaya_is_smooth_scroll',
                'type'        => 'toggle',
            )));

            /**
             * Footer section
             */
            $wp_customize->add_section(
                'sarmaya_footer', array(
                    'title'       => __('Footer', 'sarmaya'),
                    'priority'    => 28,
                    'description' => __('Customize the look & feel of your website footer.', 'sarmaya'),
                )
            );

            // Footer width
            $wp_customize->add_setting('sarmaya_is_footer_fluid', array(
                'default'           => sarmaya_defaults('is_footer_fluid'),
                'sanitize_callback' => 'sarmaya_sanitize_checkbox',
            ));
            $wp_customize->add_control(new ETCode_Toggle_Control($wp_customize, 'sarmaya_is_footer_fluid', array(
                'label'    => esc_html__('Footer Full Width', 'sarmaya'),
                'section'  => 'sarmaya_footer',
                'settings' => 'sarmaya_is_footer_fluid',
                'type'     => 'toggle',
            )));

            // Is Footer widgets
            $wp_customize->add_setting('sarmaya_is_footer_widgets', array(
                'default'           => sarmaya_defaults('is_footer_widgets'),
                'sanitize_callback' => 'sarmaya_sanitize_checkbox',
            ));
            $wp_customize->add_control(new ETCode_Toggle_Control($wp_customize, 'sarmaya_is_footer_widgets', array(
                'label'    => esc_html__('Footer Widgets', 'sarmaya'),
                'section'  => 'sarmaya_footer',
                'settings' => 'sarmaya_is_footer_widgets',
                'type'     => 'toggle',
            )));

            // Is Footer
            $wp_customize->add_setting('sarmaya_is_footer', array(
                'default'           => sarmaya_defaults('is_footer'),
                'sanitize_callback' => 'sarmaya_sanitize_checkbox',
            ));
            $wp_customize->add_control(new ETCode_Toggle_Control($wp_customize, 'sarmaya_is_footer', array(
                'label'    => esc_html__('Footer', 'sarmaya'),
                'section'  => 'sarmaya_footer',
                'settings' => 'sarmaya_is_footer',
                'type'     => 'toggle',
            )));

            /**
             * Footer Background
             */
            $wp_customize->add_setting(
                'sarmaya_footer_background_color', array(
                    'default'           => sarmaya_defaults('footer_background_color'),
                    'sanitize_callback' => 'sanitize_hex_color',
                )
            );

            $wp_customize->add_control(
                new WP_Customize_Color_Control(
                    $wp_customize, 'sarmaya_footer_background_color', array(
                        'label'    => __('Background color', 'sarmaya'),
                        'section'  => 'sarmaya_footer',
                        'settings' => 'sarmaya_footer_background_color',
                        'priority' => 10,
                    )
                )
            );

            /**
             * Footer heading color
             */
            $wp_customize->add_setting(
                'sarmaya_footer_heading_color', array(
                    'default'           => sarmaya_defaults('footer_heading_color'),
                    'sanitize_callback' => 'sanitize_hex_color',
                )
            );

            $wp_customize->add_control(
                new WP_Customize_Color_Control(
                    $wp_customize, 'sarmaya_footer_heading_color', array(
                        'label'    => __('Heading color', 'sarmaya'),
                        'section'  => 'sarmaya_footer',
                        'settings' => 'sarmaya_footer_heading_color',
                        'priority' => 20,
                    )
                )
            );

            /**
             * Footer text color
             */
            $wp_customize->add_setting(
                'sarmaya_footer_text_color', array(
                    'default'           => sarmaya_defaults('footer_text_color'),
                    'sanitize_callback' => 'sanitize_hex_color',
                )
            );

            $wp_customize->add_control(
                new WP_Customize_Color_Control(
                    $wp_customize, 'sarmaya_footer_text_color', array(
                        'label'    => __('Text color', 'sarmaya'),
                        'section'  => 'sarmaya_footer',
                        'settings' => 'sarmaya_footer_text_color',
                        'priority' => 30,
                    )
                )
            );

            /**
             * Footer link color
             */
            $wp_customize->add_setting(
                'sarmaya_footer_link_color', array(
                    'default'           => sarmaya_defaults('footer_link_color'),
                    'sanitize_callback' => 'sanitize_hex_color',
                )
            );

            $wp_customize->add_control(
                new WP_Customize_Color_Control(
                    $wp_customize, 'sarmaya_footer_link_color', array(
                        'label'    => __('Link color', 'sarmaya'),
                        'section'  => 'sarmaya_footer',
                        'settings' => 'sarmaya_footer_link_color',
                        'priority' => 40,
                    )
                )
            );

        }

        /**
         * Add CSS in <head> for styles handled by the theme customizer
         *
         * @since 1.0.0
         * @return void
         */
        public function add_customizer_css() {

            $custom_css = '';


            // Header

            $classes[] = array(
                'selector'   => '.navbar',
                'value'      => get_theme_mod('sarmaya_header_bg_color', sarmaya_defaults('header_bg_color')),
                'properties' => array(
                    'background-color',
                ),
            );

            // Site Identity

            // Logo
            $classes[] = array(
                'selector'   => '.site-header .navbar .navbar-brand',
                'value'      => get_theme_mod('sarmaya_logo_max_width') ? get_theme_mod('sarmaya_logo_max_width') . 'px' : false,
                'properties' => array(
                    'width',
                ),
            );

            // Typography - Headings

            $classes[] = array(
                'selector'   => 'h1,h2,h3,h4,h5,h6,.h1,.h2,.h3,.h4,.h5,.h6',
                'value'      => get_theme_mod('sarmaya_headings_font'),
                'properties' => array(
                    'font-family',
                ),
            );
            $classes[] = array(
                'selector'   => 'h1,h2,h3,h4,h5,h6,.h1,.h2,.h3,.h4,.h5,.h6',
                'value'      => get_theme_mod('sarmaya_headings_font_weight'),
                'properties' => array(
                    'font-weight',
                ),
            );
            $classes[] = array(
                'selector'   => 'h1,h2,h3,h4,h5,h6,.h1,.h2,.h3,.h4,.h5,.h6',
                'value'      => get_theme_mod('sarmaya_headings_font_style'),
                'properties' => array(
                    'font-style',
                ),
            );
            $classes[] = array(
                'selector'   => 'h1,h2,h3,h4,h5,h6,.h1,.h2,.h3,.h4,.h5,.h6',
                'value'      => get_theme_mod('sarmaya_headings_font_color'),
                'properties' => array(
                    'color',
                ),
            );

            // Typography - body

            $classes[] = array(
                'selector'   => 'body',
                'value'      => get_theme_mod('sarmaya_body_font'),
                'properties' => array(
                    'font-family',
                ),
            );
            $classes[] = array(
                'selector'   => 'body',
                'value'      => get_theme_mod('sarmaya_body_font_weight'),
                'properties' => array(
                    'font-weight',
                ),
            );
            $classes[] = array(
                'selector'   => 'body',
                'value'      => get_theme_mod('sarmaya_body_font_style'),
                'properties' => array(
                    'font-style',
                ),
            );
            $classes[] = array(
                'selector'   => 'body',
                'value'      => get_theme_mod('sarmaya_body_font_size') ? get_theme_mod('sarmaya_body_font_size') . 'px' : false,
                'properties' => array(
                    'font-size',
                ),
            );
            $classes[] = array(
                'selector'   => 'body',
                'value'      => get_theme_mod('sarmaya_body_font_color'),
                'properties' => array(
                    'color',
                ),
            );
            $classes[] = array(
                'selector'   => 'a:hover',
                'value'      => get_theme_mod('sarmaya_body_font_link_color') ? sarmaya_color_luminance(get_theme_mod('sarmaya_body_font_link_color'), 0.25) : false,
                'properties' => array(
                    'color',
                ),
            );

            // Typography - Menu

            $classes[] = array(
                'selector'   => '.site-header .navbar-nav .nav-item',
                'value'      => get_theme_mod('sarmaya_menu_font_size', sarmaya_defaults('menu_font_size')) ? get_theme_mod('sarmaya_menu_font_size', sarmaya_defaults('menu_font_size')) . 'px' : false,
                'properties' => array(
                    'font-size',
                ),
            );

            $classes[] = array(
                'selector'   => '.site-header .navbar-nav .nav-link',
                'value'      => get_theme_mod('sarmaya_menu_font_color'),
                'properties' => array(
                    'color',
                ),
            );

            $classes[] = array(
                'selector'   => '.site-header .navbar-nav .nav-item a:hover',
                'value'      => get_theme_mod('sarmaya_menu_font_hover_active_color'),
                'properties' => array(
                    'color',
                ),
            );

            // Colors

            // Accent color
            $classes[] = array(
                'selector'   => '
	            .site-header .navbar .navbar-nav a.active, .site-header .navbar .dropdown.active > a, .site-header .navbar .nav-item.show .nav-link,
	            .woocommerce-form-coupon-toggle .woocommerce-info a
	        ',
                'value'      => get_theme_mod('sarmaya_accent_color'),
                'properties' => array(
                    'color',
                ),
            );
            // Accent hover color
            $classes[] = array(
                'selector'   => '
	            .site-header .navbar .navbar-nav a.active, .site-header .navbar .dropdown.active > a, .site-header .navbar .nav-item.show .nav-link,
	            .woocommerce-form-coupon-toggle .woocommerce-info a
	        ',
                'value'      => get_theme_mod('sarmaya_accent_color') ? sarmaya_color_luminance(get_theme_mod('sarmaya_accent_color'), 0.15) : false,
                'properties' => array(
                    'color',
                ),
            );

            // Accent background color
            $classes[] = array(
                'selector'   => '
	            .cart-collaterals .cart_totals.calculated_shipping .wc-proceed-to-checkout .checkout-button,
	            .onsale,
	            .woocommerce-account .woocommerce-MyAccount-navigation li.is-active a

	        ',
                'value'      => get_theme_mod('sarmaya_accent_color'),
                'properties' => array(
                    'background-color',
                ),
            );
            // Accent hover background color
            $classes[] = array(
                'selector'   => '
	            .cart-collaterals .cart_totals.calculated_shipping .wc-proceed-to-checkout .checkout-button:hover,
	            .onsale:hover
	        ',
                'value'      => get_theme_mod('sarmaya_accent_color') ? sarmaya_color_luminance(get_theme_mod('sarmaya_accent_color'), 0.05) : false,
                'properties' => array(
                    'background-color',
                ),
            );

            // Accent border color
            $classes[] = array(
                'selector'   => '
	            .cart-collaterals .cart_totals.calculated_shipping .wc-proceed-to-checkout .checkout-button

	        ',
                'value'      => get_theme_mod('sarmaya_accent_color'),
                'properties' => array(
                    'border-color',
                ),
            );
            // Accent hover border color
            $classes[] = array(
                'selector'   => '
	            .cart-collaterals .cart_totals.calculated_shipping .wc-proceed-to-checkout .checkout-button:hover
	        ',
                'value'      => get_theme_mod('sarmaya_accent_color') ? sarmaya_color_luminance(get_theme_mod('sarmaya_accent_color'), 0.05) : false,
                'properties' => array(
                    'border-color',
                ),
            );

            // Accent Background color
            $classes[] = array(
                'selector'   => '
                .dropdown-item:hover, .dropdown-item:focus,
                .blog-slider.blog-post.sarmaya-slider-one article .entry-content-wrapper,
                .wp-block-search__input,
                .wp-block-search__button,
                .wp-block-search__button:before,
                .woocommerce-product-search button:before,
                .entry-tags li a,
                .card-post-style article .entry-content-wrapper,
                .simple-entry-list.blog-post article,
                .widget ul.product-filterBySize li a,
                .product-filterBySize li a,
                .flickity-prev-next-butto,
                .slick-dots li button,
                .has-background:not([class*="background-color"]),
                .entry-content .wp-block-latest-posts .is-grid li,
                .wp-block-verse,
                .search-form .form-control,
                .search-form .btn,
                ul.order_details,
                form.checkout_coupon.woocommerce-form-coupon,
                .woocommerce-form-coupon-toggle .woocommerce-info,
                form.woocommerce-checkout .order_review_container .woocommerce-checkout-review-order,
                .woocommerce table.shop_table thead td,
                .woocommerce table.shop_table thead th,
                .woocommerce table.shop_table tfoot td,
                .woocommerce table.shop_table tfoot th,
                .woocommerce-page table.shop_table thead td,
                .woocommerce-page table.shop_table thead th,
                .woocommerce-page table.shop_table tfoot td,
                .woocommerce-page table.shop_table tfoot th,
                .woocommerce table.shop_table:not(.order_details) tbody tr:nth-of-type(even),
                .woocommerce-page table.shop_table:not(.order_details) tbody tr:nth-of-type(even),
                .woocommerce-product-search .search-field,
                .woocommerce-product-search .search-field,
                .woocommerce-product-search .search-field button:focus,
                .woocommerce-product-search .search-field button:before,
                .woocommerce-form-coupon-toggle .woocommerce-info,
                .woocommerce-account .woocommerce-MyAccount-navigation li a,
                .cart-collaterals .cart_totals.calculated_shipping
            ',
                'value'      => get_theme_mod('sarmaya_accent_bg_color'),
                'properties' => array(
                    'background-color',
                ),
            );

            if (get_theme_mod('sarmaya_accent_bg_color')) {
                $custom_css .= '
	        .cart-collaterals .cart_totals.calculated_shipping:before, .cart-collaterals .cart_totals.calculated_shipping:after,
	        form.checkout_coupon.woocommerce-form-coupon:before, form.checkout_coupon.woocommerce-form-coupon:after,
	        form.woocommerce-checkout .order_review_container .woocommerce-checkout-review-order:before, form.woocommerce-checkout .order_review_container .woocommerce-checkout-review-order:after,
	        ul.order_details::before, ul.order_details::after
	        {
	            background: -webkit-linear-gradient(transparent 0, transparent 0),
	                -webkit-linear-gradient(135deg, ' . get_theme_mod('sarmaya_accent_bg_color') . ' 33.33%, transparent 33.33%),
                    -webkit-linear-gradient(45deg, ' . get_theme_mod('sarmaya_accent_bg_color') . ' 33.33%, transparent 33.33%);
                background-size: 0 100%, 16px 16px, 16px 16px;
	        }';
            }

            // Accent Background border
            $classes[] = array(
                'selector'   => '
	        .wp-block-search__input,
	        .wp-block-search__button,
            .woocommerce-product-search .search-field button,
            .woocommerce-product-search .search-field
	        ',
                'value'      => get_theme_mod('sarmaya_accent_bg_color'),
                'properties' => array(
                    'border-color',
                ),
            );

            // Accent Background hover
            $classes[] = array(
                'selector'   => '
	        .entry-tags li a:hover',
                'value'      => get_theme_mod('sarmaya_accent_bg_color') ? sarmaya_color_luminance(get_theme_mod('sarmaya_accent_bg_color'), 0.1) : false,
                'properties' => array(
                    'background',
                ),
            );

            $classes[] = array(
                'selector'   => '
	            .btn,
	            button,
	            .button,
	            .added_to_cart,
	            input[type=submit],
	            input[type=button]
	        ',
                'value'      => get_theme_mod('sarmaya_btn_text_color'),
                'properties' => array(
                    'color',
                ),
            );

            $classes[] = array(
                'selector'   => '
	            .btn:hover, button:hover, .button:hover, .added_to_cart:hover, input[type=submit]:hover, input[type=button]:hover
	        ',
                'value'      => get_theme_mod('sarmaya_btn_text_hover_color'),
                'properties' => array(
                    'color',
                ),
            );

            $classes[] = array(
                'selector'   => '
	            .btn,
	            button,
	            .button,
	            .added_to_cart,
	            input[type=submit],
	            input[type=button]
	        ',
                'value'      => get_theme_mod('sarmaya_btn_background_color'),
                'properties' => array(
                    'background-color',
                ),
            );

            $classes[] = array(
                'selector'   => '
	            .btn:hover,
	            button:hover,
	            .button:hover,
	            .added_to_cart:hover,
	            input[type=submit]:hover,
	            input[type=button]:hover
	        ',
                'value'      => get_theme_mod('sarmaya_btn_background_hover_color'),
                'properties' => array(
                    'background-color',
                ),
            );

            /*******************************************
            Footer
             ********************************************/

            // Footer Background
            $classes[] = array(
                'selector'   => '.site-footer',
                'value'      => get_theme_mod('sarmaya_footer_background_color'),
                'properties' => array(
                    'background-color',
                ),
            );

            // Footer divider
            $classes[] = array(
                'selector'   => '.site-footer .footer-bottom-area',
                'value'      => get_theme_mod('sarmaya_footer_background_color') ? sarmaya_color_luminance(get_theme_mod('sarmaya_footer_background_color'), 0.1) : false,
                'properties' => array(
                    'border-top-color',
                ),
            );

            // Footer widget title color
            $classes[] = array(
                'selector'   => '.site-footer .widget .widget-title',
                'value'      => get_theme_mod('sarmaya_footer_heading_color'),
                'properties' => array(
                    'color',
                ),
            );

            // Footer text color
            $classes[] = array(
                'selector'   => '.site-footer',
                'value'      => get_theme_mod('sarmaya_footer_text_color'),
                'properties' => array(
                    'color',
                ),
            );

            // Footer link color
            $classes[] = array(
                'selector'   => '.site-footer a',
                'value'      => get_theme_mod('sarmaya_footer_link_color'),
                'properties' => array(
                    'color',
                ),
            );

            // Footer link color hover
            $classes[] = array(
                'selector'   => '.site-footer a:hover',
                'value'      => get_theme_mod('sarmaya_footer_link_color') ? sarmaya_color_luminance(get_theme_mod('sarmaya_footer_link_color'), 0.25) : false,
                'properties' => array(
                    'color',
                ),
            );

            // Add css value of each setting

            foreach ($classes as $class) {

                if ($class['value'] && !empty($class['value']) && $class['value'] !== 'px') {
                    foreach ($class['properties'] as $property) {
                        $custom_css .= $class['selector'] . ' {' . $property . ': ' . $class['value'] . ';}';
                    }
                }
            }

            wp_add_inline_style('sarmaya-style', wp_strip_all_tags($custom_css));
        }

        /**
		 * Enqueue dynamic colors to use editor blocks.
		 *
		 * @since 1.0.0
		 */
		public function block_editor_customizer_css() {

            $styles = '';
            
			wp_add_inline_style( 'sarmaya-editor-block-styles', $styles );
		}
    }

endif;

return new Sarmaya_Customizer();
