<?php
/**
 * Jetpack Compatibility File
 * See: http://jetpack.me/
 *
 * @package     Sarmaya
 * @author      Amjad Ali
 * @license     http://www.gnu.org/licenses/gpl-3.0.html GNU Public License
 */

/**
 * Add JetPack support.
 */
function sarmaya_jetpack_setup() {

	/**
	 * Add support for JetPack Infinite scrolling.
	 *
	 * @see https://jetpack.com/support/infinite-scroll/
	 * @since Sarmaya 1.0.5
	 */
	add_theme_support(
		'infinite-scroll', array(
			'container' => 'main',
			'footer'    => false,
			'render'    => 'sarmaya_infinite_scroll',
		)
	);

}
add_action( 'after_setup_theme', 'sarmaya_jetpack_setup' );

/**
 * Custom Infinite Scroll Render function.
 */
function sarmaya_infinite_scroll() {
	while ( have_posts() ) {
		the_post();
		get_template_part( 'template-parts/post/content', get_post_format() );
	}
}

/**
 * Filter Jetpack's Infinite Scroll text on button that loads more posts.
 *
 * @param array $settings An array of settings for infinite scroll.
 */
function sarmaya_filter_jetpack_infinite_scroll_button_text( $settings ) {

	$text = apply_filters( 'sarmaya_infinite_scroll_button_text', esc_html__( 'Load More...', 'sarmaya' ) );

	$settings['text'] = esc_html( $text );

	return $settings;
}
add_filter( 'infinite_scroll_js_settings', 'sarmaya_filter_jetpack_infinite_scroll_button_text' );
