<?php
/**
 * Sarmaya Jetpack Class
 *
 * @package  Sarmaya
 * @since    1.0.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

if ( ! class_exists( 'Sarmaya_Jetpack' ) ) :

	/**
	 * The Sarmaya Jetpack integration class
	 */
	class Sarmaya_Jetpack {

		/**
		 * Setup class.
		 *
		 * @since 1.0
		 */
		public function __construct() {
			add_action( 'init', array( $this, 'jetpack_setup' ) );
			add_action( 'wp_enqueue_scripts', array( $this, 'jetpack_scripts' ), 10 );

			if ( sarmaya_is_woocommerce_activated() ) {
				add_action( 'init', array( $this, 'jetpack_infinite_scroll_wrapper_columns' ) );
			}
		}

		/**
		 * Add theme support for Infinite Scroll.
		 * See: http://jetpack.me/support/infinite-scroll/
		 */
		public function jetpack_setup() {
			add_theme_support(
				'infinite-scroll', apply_filters(
					'sarmaya_jetpack_infinite_scroll_args', array(
						'container'      => 'infinite-scroll-container',
						'footer'         => 'page',
						'render'         => array( $this, 'jetpack_infinite_scroll_loop' ),
						'footer_widgets' => array(
							'footer-1',
							'footer-2',
							'footer-3',
							'footer-4',
						),
					)
				)
			);
		}

		/**
		 * A loop used to display content appended using Jetpack infinite scroll
		 *
		 * @return void
		 */
		public function jetpack_infinite_scroll_loop() {
			do_action( 'sarmaya_jetpack_infinite_scroll_before' );

			if ( function_exists( 'sarmaya_is_product_archive' ) && sarmaya_is_product_archive() ) {
				do_action( 'sarmaya_jetpack_product_infinite_scroll_before' );
				woocommerce_product_loop_start();
			}

			while ( have_posts() ) :
				the_post();
				if ( function_exists( 'sarmaya_is_product_archive' ) && sarmaya_is_product_archive() ) {
					wc_get_template_part( 'content', 'product' );
				} else {

					?> 
					<div class="<?php echo esc_attr(get_theme_mod( 'sarmaya_blog_post_layout_col', sarmaya_defaults( 'blog_post_layout_col' ))); ?>">
						
						<?php get_template_part( 'template-parts/post/content', get_post_format() ); ?>
					
					</div> <?php
				}

			endwhile; // end of the loop.

			if ( function_exists( 'sarmaya_is_product_archive' ) && sarmaya_is_product_archive() ) {
				woocommerce_product_loop_end();
				do_action( 'sarmaya_jetpack_product_infinite_scroll_after' );
			}

			do_action( 'sarmaya_jetpack_infinite_scroll_after' );
		}

		/**
		 * Adds columns wrapper to content appended by Jetpack infinite scroll
		 *
		 * @return void
		 */
		public function jetpack_infinite_scroll_wrapper_columns() {
			add_action( 'sarmaya_jetpack_product_infinite_scroll_before', 'sarmaya_product_columns_wrapper' );
			add_action( 'sarmaya_jetpack_product_infinite_scroll_after', 'sarmaya_product_columns_wrapper_close' );
		}

		/**
		 * Enqueue jetpack styles.
		 *
		 * @since  1.0.0
		 */
		public function jetpack_scripts() {
			
		}
	}

endif;

return new Sarmaya_Jetpack();
