<?php
/**
 * Additional features to allow styling of the templates.
 *
 * Eventually, some of the functionality here could be replaced by core features.
 *
 * @package     Sarmaya
 * @author      Amjad Ali
 * @license     http://www.gnu.org/licenses/gpl-3.0.html GNU Public License
 */

if (!function_exists('sarmaya_is_woocommerce_activated')) {
    /**
     * Query WooCommerce activation
     */
    function sarmaya_is_woocommerce_activated() {
        return class_exists('WooCommerce') ? true : false;
    }
}

/**
 * Adds custom class to the array of posts classes.
 */
function sarmaya_post_classes($classes, $class, $post_id) {

    $classes[] = 'entry';

    return $classes;
}
add_filter('post_class', 'sarmaya_post_classes', 10, 3);

/**
 * Add modules to primary navbar
 */
function sarmaya_navbar_modules($items, $args) {

    if ('primary' == $args->theme_location) {

        // Add search form
        if (true === get_theme_mod('sarmaya_is_navbar_search_form', sarmaya_defaults('is_navbar_search_form'))) {
            $items .= '<li class="menu-item nav-item-search">'
            . '<form role="search" method="get" class="form-inline navbar-search-bar" action="' . home_url('/') . '">'
            . '<label>'
            . '<span class="screen-reader-text">' . esc_html_x('Search for:', 'label', 'sarmaya') . '</span>'
            . '</label>'
            . '<input type="search" class="search-field" placeholder="' . esc_attr('Search …', 'sarmaya') . '" value="' . get_search_query() . '" name="s" title="' . esc_attr('Search for:', 'label', 'sarmaya') . '" />'

                . '<div class="input-group-append">'
                . '<button class="btn" type="submit"><i class="fa fa-search" aria-hidden="true"></i> <span class="screen-reader-text">Search</span> </button>'
                . '</div>'

                . '</form>'
                . '</li>';
        }

        // Add social nav
        if (true === get_theme_mod('sarmaya_is_navbar_social_nav', sarmaya_defaults('is_navbar_social_nav')) && has_nav_menu('social')) {

            $args_social_nav = array(
                'theme_location' => 'social',
                'container'      => false,
                'echo'           => false,
                'items_wrap'     => '%3$s',
                'depth'          => 0,
                'link_before'    => '<span class="screen-reader-text">',
                'link_after'     => '</span>',
            );

           // $items .= '<li class="nav-item-social-nav d-flex align-items-center">' . strip_tags(wp_nav_menu($args_social_nav), '<a>, <span>, <svg>, <i>') . '</li>';

        }

        // Add Shopping cart
        if (sarmaya_is_woocommerce_activated()) {
            if (true === get_theme_mod('sarmaya_is_navbar_shopping_cart', sarmaya_defaults('is_navbar_shopping_cart'))) {

                $items .= sarmaya_header_cart();

            }
        }

        // Add search form
        if (true === get_theme_mod('sarmaya_is_navbar_shopping_cart', sarmaya_defaults('is_navbar_shopping_cart'))) {

            $items .= '<li class="menu-item nav-item nav-item-account">';

            if (is_user_logged_in()) {
                $items .= '<a class="nav-link" href="' . get_permalink(get_option('woocommerce_myaccount_page_id')) . '" title="' . esc_attr__('My Account', 'sarmaya') . '"><i class="fas fa-user-circle"></i> ' . esc_html__('My Account', 'sarmaya') . '</a>';
            } else {
                $items .= '<a class="nav-link" href="' . get_permalink(get_option('woocommerce_myaccount_page_id')) . '" title="' . esc_attr__('Login / Register', 'sarmaya') . '"><i class="fas fa-user-circle"></i> ' . esc_html__('Login / Register', 'sarmaya') . '</a>';
            }

            $items .= '</li>';
        }

    }

    return $items;

}
add_filter('wp_nav_menu_items', 'sarmaya_navbar_modules', 10, 2);

/**
 * Returns an array of supported social links (URL and icon name).
 *
 * @return array $social_links_icons
 */
function sarmaya_social_links_icons() {

    $social_links_icons = array(
        '500px.com'        => '500px',
        'amazon.com'       => 'amazon',
        'bandsintown.com'  => 'bandsintown',
        'behance.net'      => 'behance',
        'chownow.com'      => 'chownow',
        'codepen.io'       => 'codepen',
        'dribbble.com'     => 'dribbble',
        'dropbox.com'      => 'dropbox',
        'facebook.com'     => 'facebook',
        '/feed'            => 'rss',
        'flickr.com'       => 'flickr',
        'foursquare.com'   => 'foursquare',
        'plus.google.com'  => 'google',
        'github.com'       => 'github',
        'instagram.com'    => 'instagram',
        'itunes'           => 'itunes',
        'itunes.apple.com' => 'itunes',
        'linkedin.com'     => 'linkedin',
        'mailto:'          => 'email',
        'medium.com'       => 'medium',
        'meetup.com'       => 'meetup',
        'pinterest.com'    => 'pinterest',
        'quora.com'        => 'quora',
        'reddit.com'       => 'reddit',
        'smugmug.net'      => 'smugmug',
        'snapchat.com'     => 'snapchat-ghost',
        'soundcloud.com'   => 'soundcloud',
        'spotify.com'      => 'spotify',
        'stumbleupon.com'  => 'stumbleupon',
        'tumblr.com'       => 'tumblr',
        'twitch.tv'        => 'twitch',
        'twitter.com'      => 'twitter',
        'vimeo.com'        => 'vimeo',
        'vine.co'          => 'vine',
        'vevo.com'         => 'vevo',
        'vsco.co'          => 'vsco',
        'wordpress.org'    => 'wordpress',
        'wordpress.com'    => 'wordpress',
        'yelp.com'         => 'yelp',
        'youtube.com'      => 'youtube',
        'mastodon.social'  => 'mastodon',
        'norden.social'    => 'mastodon',
    );

    return apply_filters('sarmaya_social_links_icons', $social_links_icons);
}

/**
 * Display icons in social links menu.
 *
 * @param  string  $item_output The menu item output.
 * @param  WP_Post $item        Menu item object.
 * @param  int     $depth       Depth of the menu.
 * @param  array   $args        wp_nav_menu() arguments.
 * @return string  $item_output The menu item output with social icon.
 */
function sarmaya_nav_menu_social_icons($item_output, $item, $depth, $args) {
    // Get supported social icons.
    $social_icons = sarmaya_social_links_icons();

    // Change icon inside social links menu if there is supported URL.
  
    if ('social' === $args->theme_location || 'footer' === $args->theme_location) {
     
        foreach ($social_icons as $attr => $value) {
            if (false !== strpos($item_output, $attr)) {
              
                $item_output = str_replace($args->link_after, '</span><i class="fab fa-' . esc_attr($value) . ' "></i>', $item_output);
               
            }
        }
    }

    return $item_output;
}
add_filter('walker_nav_menu_start_el', 'sarmaya_nav_menu_social_icons', 10, 4);
 
/*********  Get all register Image sizes *********/

function sarmaya_get_image_sizes() {
    $sizes = array();
    foreach (get_intermediate_image_sizes() as $_size) {
        $label         = preg_replace('/_/', ' ', $_size);
        $label         = ucfirst($label);
        $sizes[$_size] = $label;
    }
    ;
    return $sizes;
}

/********* Get an array of all footers *********/
if (!function_exists('sarmaya_footers_list')):

    function sarmaya_footers_list() {
        $args = array(
            'post_type'   => 'etcodes-footer',
            'numberposts' => -1,
        );
        $pages          = get_posts($args);
        $result         = array();
        $result['none'] = esc_html__('None', 'sarmaya');
        foreach ($pages as $page) {
            $result[$page->ID] = $page->post_title;
        }

        return $result;
    }

endif;

/**
 * Get the content background color
 * Accounts for the Storefront Designer and Storefront Powerpack content background option.
 *
 * @since  1.6.0
 * @return string the background color
 */
function sarmaya_get_content_background_color() {
    if (class_exists('Storefront_Designer')) {
        $content_bg_color = get_theme_mod('sd_content_background_color');
        $content_frame    = get_theme_mod('sd_fixed_width');
    }

    if (class_exists('Storefront_Powerpack')) {
        $content_bg_color = get_theme_mod('sp_content_frame_background');
        $content_frame    = get_theme_mod('sp_content_frame');
    }

    $bg_color = str_replace('#', '', get_theme_mod('background_color'));

    if (class_exists('Storefront_Powerpack') || class_exists('Storefront_Designer')) {
        if ($content_bg_color && ('true' === $content_frame || 'frame' === $content_frame)) {
            $bg_color = str_replace('#', '', $content_bg_color);
        }
    }

    return '#' . $bg_color;
}

/**
 * Adjust a hex color brightness
 * Allows us to create hover styles for custom link colors
 *
 * @param  strong  $hex   hex color e.g. #111111.
 * @param  integer $steps factor by which to brighten/darken ranging from -255 (darken) to 255 (brighten).
 * @return string        brightened/darkened hex color
 * @since  1.0.0
 */
function sarmaya_adjust_color_brightness($hex, $steps) {
    // Steps should be between -255 and 255. Negative = darker, positive = lighter.
    $steps = max(-255, min(255, $steps));

    // Format the hex color string.
    $hex = str_replace('#', '', $hex);

    if (3 === strlen($hex)) {
        $hex = str_repeat(substr($hex, 0, 1), 2) . str_repeat(substr($hex, 1, 1), 2) . str_repeat(substr($hex, 2, 1), 2);
    }

    // Get decimal values.
    $r = hexdec(substr($hex, 0, 2));
    $g = hexdec(substr($hex, 2, 2));
    $b = hexdec(substr($hex, 4, 2));

    // Adjust number of steps and keep it inside 0 to 255.
    $r = max(0, min(255, $r + $steps));
    $g = max(0, min(255, $g + $steps));
    $b = max(0, min(255, $b + $steps));

    $r_hex = str_pad(dechex($r), 2, '0', STR_PAD_LEFT);
    $g_hex = str_pad(dechex($g), 2, '0', STR_PAD_LEFT);
    $b_hex = str_pad(dechex($b), 2, '0', STR_PAD_LEFT);

    return '#' . $r_hex . $g_hex . $b_hex;
}

/**
 * Adds custom class to the array of posts classes.
 */
function sarmaya_post_carousel_styles($postsCarouselStyleList) {

    $postsCarouselStyleList[] = array('value' => 'sarmaya-slider-one', 'label' => 'Sarmaya Carousel One');
    return $postsCarouselStyleList;

}
add_filter('ete_post_carousel_style_list_filter', 'sarmaya_post_carousel_styles');

if (!function_exists('sarmaya_footer_widgets')) {
    /**
     * Display the footer widget regions.
     *
     * @since  1.0.0
     * @return void
     */
    function sarmaya_footer_widgets() {

        $container         = (false === get_theme_mod('sarmaya_is_footer_fluid', sarmaya_defaults('is_footer_fluid'))) ? 'container' : 'container-fluid';
        $is_footer_widgets = get_theme_mod('sarmaya_is_footer_widgets', sarmaya_defaults('is_footer_widgets'));
        $is_footer         = get_theme_mod('sarmaya_is_footer', sarmaya_defaults('is_footer'));
        $rows              = intval(apply_filters('sarmaya_footer_widget_rows', 1));
        $regions           = intval(apply_filters('sarmaya_footer_widget_columns', 5));

        ?>

        <div class="<?php echo esc_attr($container); ?>">

        <?php
        if ($is_footer_widgets) {
            for ($row = 1; $row <= $rows; $row++):

                // Defines the number of active columns in this footer row.
                for ($region = $regions; 0 < $region; $region--) {
                    if (is_active_sidebar('footer-' . esc_attr($region + $regions * ($row - 1)))) {
                        $columns = $region;
                        break;
                    }
                }

                if (isset($columns)):
                ?>
				<div class=<?php echo '"footer-widgets d-lg-flex"'; ?>>
	                <?php
                for ($column = 1; $column <= $columns; $column++):
                    $footer_n = $column + $regions * ($row - 1);

                    if (is_active_sidebar('footer-' . esc_attr($footer_n))):
                    ?>
						    	<div class="footer-widget footer-widget-<?php echo esc_attr($column); ?>">
						    		<?php dynamic_sidebar('footer-' . esc_attr($footer_n));?>
						    	</div>
						    		<?php
                endif;
            endfor;
            ?>
			    </div><!-- .footer-widgets.row-<?php echo esc_attr($row); ?> -->
				<?php
                    unset($columns);
            endif;
            endfor;
        }

        if ($is_footer) {
            ?>
		    <div class="footer-bottom-area">

		        <div class="row large-gutters">

				  	<div class="col-md-6">
                        <div class="footer-widget">
		                    <p class="m-md-0"><a href="<?php echo esc_url(home_url('/')); ?>" rel="home">&copy; <?php echo esc_html(date_i18n('Y')); ?> <?php bloginfo('name');?></a></p>
		                </div>
		        	</div>

		        	<div class="col-md-6">
                        <div class="footer-widget">
					    <?php if (has_nav_menu('footer')): ?>
						    <nav class="footer-navigation" aria-label="<?php esc_attr_e('Footer Menu', 'sarmaya');?>">
                            
                            <?php
                                wp_nav_menu(
                                    array(
                                        'theme_location' => 'footer',
                                        'menu_class'     => 'footer-menu list-inline m-0 p-0 text-md-right footer-nav',
                                        'depth'          => 1,
                                        'link_before'    => '<span class="screen-reader-text">',
                                        'link_after'     => '</span>',
                                    )
                                );
                            ?>

							</nav>
						<?php endif;?>
                        </div>
		            </div>

				</div>

		    </div>
		<?php }?>

        </div>

        <?php

    }
}
add_action('sarmaya_footer', 'sarmaya_footer_widgets', 10);