<?php
/**
 * Custom template tags for this theme.
 *
 * Eventually, some of the functionality here could be replaced by core features.
 *
 * @package     Sarmaya
 * @author      Amjad Ali
 * @license     http://www.gnu.org/licenses/gpl-3.0.html GNU Public License
 */


if ( ! function_exists( 'sarmaya_site_logo' ) ) :
	/**
	 * Output an <img> tag of the site logo.
	 */
	function sarmaya_site_logo() {

		// Let's check to see if the option is enabled via the Customizer.
		$visibility = has_custom_logo() == false ? ' ' : 'screen-reader-text';

		do_action( 'sarmaya_before_site_logo' );

		printf( 
			'<h1 class="h3 navbar-brand py-3 site-title %1$s" itemscope itemtype="http://schema.org/Organization"><a href="%2$s" rel="home" itemprop="url" class="black">%3$s</a></h1>', 
			esc_attr( $visibility ), 
			esc_url( home_url( '/' ) ), 
			esc_html( get_bloginfo( 'name' ) ) 
		);

		if (function_exists('the_custom_logo') && has_custom_logo()) {
			printf(
				'<a href="%1$s" rel="home" class="navbar-brand">%2$s %3$s <span class="site-description small d-block %4$s">%5$s</span></a>',
				esc_url( home_url( '/' ) ),
				wp_get_attachment_image(get_theme_mod('custom_logo'), 'full', false, array("class" => "etcodes-normal-logo")),
				wp_get_attachment_image(get_theme_mod('sarmaya_logo_light'), 'full', false, array("class" => "etcodes-light-logo")),
				(false === get_theme_mod( 'sarmaya_is_header_tagline') ) ? ' screen-reader-text' : null,
				esc_html(get_bloginfo('description', 'display'))
			);
		}

		do_action( 'sarmaya_after_site_logo' );
	}
endif;


if ( ! function_exists( 'sarmaya_post_thumbnail' ) ) :
	/**
	 * Display an optional post thumbnail.
	 *
	 * Wraps the post thumbnail in an anchor element on index views, or a div
	 * element when on single views.
	 */
	function sarmaya_post_thumbnail() {

		global $post;

		if ( post_password_required() || is_attachment() ) {
			return;
		}

		if ( '' !== get_the_post_thumbnail() ) {
		?>

			<figure class="entry-media alignwide">

				<?php
				
				if ( is_singular() ) {
					
					if (get_theme_mod('sarmaya_is_blog_single_post_featured_image', sarmaya_defaults( 'is_blog_single_post_featured_image' ) ) ) {
						the_post_thumbnail( get_theme_mod('sarmaya_blog_single_post_featured_image_size', sarmaya_defaults( 'blog_single_post_featured_image_size' )) );
					}
					
				} else {
					
					if (get_theme_mod('sarmaya_is_blog_post_featured_image', sarmaya_defaults( 'is_blog_post_featured_image' ) ) ) { ?>

						<a class="post-thumbnail" href="<?php esc_url( the_permalink() ); ?>" aria-hidden="true">
							<?php the_post_thumbnail( get_theme_mod('sarmaya_blog_posts_featured_image_size', sarmaya_defaults( 'blog_posts_featured_image_size' )) ); ?>
						</a>

					<?php }

				}
				?>

			</figure>

			<?php
		}
	}
endif;

if ( ! function_exists( 'sarmaya_categories' ) ) :
	/**
	 * Prints HTML with meta information for the categories.
	 */
	function sarmaya_categories() {
		if ( 'post' === get_post_type() ) {

			// Let's check to see if the option is enabled via the Customizer.
			$option     = get_theme_mod( 'categories', sarmaya_defaults( 'categories' ) );
			$visibility = ( false === $option ) ? ' hidden' : null;

			if ( ! $option && ! is_customize_preview() ) {
				return;
			}

			/* translators: used between list items, there is a space after the comma */
			$categories_list = get_the_category_list( '' );

			if ( $categories_list && sarmaya_categorized_blog() ) {
				printf( '<span class="cat-links sans-serif-font extra-small medium smooth dark-gray %1$s">%2$s</span>', esc_attr( $visibility ), $categories_list ); // WPCS: XSS OK.
			}
		}
	}
endif;

if ( ! function_exists( 'sarmaya_tags' ) ) :
	/**
	 * Prints HTML with meta information for the categories, tags and comments.
	 */
	function sarmaya_tags() {

		// Hide category and tag text for pages.
		if ( is_singular() && 'post' === get_post_type() ) {

			// Let's check to see if the option is enabled via the Customizer.
			$option     = get_theme_mod( 'tags', sarmaya_defaults( 'tags' ) );
			$visibility = ( false === $option ) ? ' hidden' : null;

			if ( ! $option && ! is_customize_preview() ) {
				return;
			}

			$tags_list = get_the_tag_list( '', '' );

			if ( ! $tags_list ) {
				return;
			}

			if ( $tags_list ) {
				printf( '<span class="tags-links sans-serif-font extra-small medium smooth dark-gray %1$s">%2$s</span>', esc_attr( $visibility ), $tags_list ); // WPCS: XSS OK.
			}
		}
	}
endif;


if ( ! function_exists( 'sarmaya_single_entry_meta_top' ) ) :
	// blog post - meta top
	function sarmaya_single_entry_meta_top(){
		?>
        <div class="entry-meta-top">

						<?php if (get_theme_mod('sarmaya_is_blog_post_categories', sarmaya_defaults( 'is_blog_post_categories' ) )) {?>
                <span class="entry-meta-category"><i class="far fa-folder"></i> <?php the_category( ', ' );?> </span>
            <?php } ?>

            <?php if (get_theme_mod('sarmaya_is_blog_post_author', sarmaya_defaults( 'is_blog_post_author' ) )) { ?>
                <span class="entry-author"><i class="far fa-user"></i> <?php esc_html_e('By ', 'sarmaya'); ?> <a href="<?php echo esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ); ?>"><?php echo get_the_author(); ?></a></span>
            <?php } ?>

            <?php if (get_theme_mod('sarmaya_is_blog_post_date', sarmaya_defaults( 'is_blog_post_date' ) )) {?>
              <span class="entry-meta-data"><i class="far fa-clock"></i> <?php echo get_the_date(); ?></span>
            <?php }?>

            <?php if (get_theme_mod('sarmaya_is_blog_post_comments_counter', sarmaya_defaults( 'is_blog_post_comments_counter' ))) { ?>
                <span class="entry-comment-counter"><i class="far fa-comment-alt"></i> <?php comments_number('0 Comments', '1 Comment', '% Comments');?></span>
            <?php } ?>

			<?php
				if (get_theme_mod('sarmaya_is_blog_post_edit_btn', sarmaya_defaults( 'is_blog_post_edit_btn' ))) {
					// Edit post link.
					edit_post_link(
						sprintf(
							wp_kses(
								/* translators: %s: Name of current post. Only visible to screen readers. */
								__( 'Edit <span class="screen-reader-text">%s</span>', 'sarmaya' ),
								array(
									'span' => array(
										'class' => array(),
									),
								)
							),
							get_the_title()
						),
						'<span class="entry-meta-edit-link"><i class="far fa-edit"></i> ',
						'</span>'
					);
				}
			?>

        </div>
        <?php
	}
endif;


if ( ! function_exists( 'sarmaya_entry_content' ) ) :
	// blog post - content
	function sarmaya_entry_content(){
		
		if ( is_single() ) :

			the_content();

		else:

			if (get_theme_mod('sarmaya_is_blog_post_content', sarmaya_defaults( 'is_blog_post_content' ))) {

				if (get_theme_mod('sarmaya_is_blog_post_excerpt', sarmaya_defaults( 'is_blog_post_excerpt' ))) :

					$limit = get_theme_mod('sarmaya_blog_post_excerpt_length', sarmaya_defaults( 'blog_post_excerpt_length' ));
					
					$post_excerpt = explode(' ', get_the_excerpt(), $limit);
					
        	if (count($post_excerpt) >= $limit) {

        	    array_pop($post_excerpt);
							$post_excerpt = implode(" ", $post_excerpt) . '...';
        	} else {

							$post_excerpt = implode(" ", $post_excerpt);
							
        	}

        	$post_excerpt = preg_replace('`\[[^\]]*\]`', '', $post_excerpt);
					
					echo '<p>' . wp_kses_post($post_excerpt) . '</p>';

				else:

					the_content();

				endif;
				
    	}

		endif;

	}
endif;

if ( ! function_exists( 'sarmaya_single_entry_footer' ) ) :
	// blog post - footer
    function sarmaya_single_entry_footer() {
		
		if ( is_single() ) : ?>

			<?php if (get_theme_mod('sarmaya_is_blog_post_tags', sarmaya_defaults( 'is_blog_post_tags' ) )) { ?>
				
				<div class="entry-meta-bottom mt-6">
				
					<?php the_tags('<ul class="entry-tags"> <li class="tags-icon"><i class="fas fa-tags"></i></li> <li>', '</li><li>', '</li></ul>'); ?>	  
				
				</div> 

			<?php } ?>
		
		<?php  else :  ?>

			<?php if (get_theme_mod('sarmaya_is_blog_post_read_more_btn', sarmaya_defaults( 'is_blog_post_read_more_btn' ) )) { ?>

				<a class="entry-read-more mt-3" href="<?php the_permalink();?>"><?php esc_html_e('Read More', 'sarmaya'); ?> <i class="fas fa-long-arrow-alt-right ml-1"></i></a>
			
			<?php } ?>

		<?php  endif; ?>
	  
	<?php }
	
endif;

if (!function_exists('sarmaya_single_entry_author_details')) :
	// blog post - Author Details
    function sarmaya_single_entry_author_details() {

        if (get_theme_mod('sarmaya_single_post_author_box', false) && get_the_author_meta("description") !== '') : ?>
        

		<div class="entry-author-container">

          <div class="row">
            
			<div class="col-md-3">
            	<?php echo get_avatar(get_the_author_meta('email'), '200'); ?>
            </div>

            <div class="col-md-9">
				<small class="caps"> <?php esc_html_e('Written by', 'sarmaya'); ?> </small>
              <h5><?php the_author_posts_link();?></h5>
              <p><?php the_author_meta("description");?> </p>
              <ul class="list-inline mb-0">
                <?php
                $url = get_the_author_meta("url");
                $facebook = get_the_author_meta("facebook");
                $twitter = get_the_author_meta("twitter");
                $linkedin = get_the_author_meta("linkedin");
                $instagram = get_the_author_meta("instagram");
                $pinterest = get_the_author_meta("pinterest");
                $tumblr = get_the_author_meta("tumblr");
                $googleplus = get_the_author_meta("googleplus");
                ?>
                <?php if (!empty($url)) {?>
                  <li class="list-inline-item">
                    <a href="<?php echo esc_url($url); ?>"><i class="fa fa-link" aria-hidden="true"></i></a>
                  </li>
                <?php }?>
                <?php if (!empty($facebook)) {?>
                  <li class="list-inline-item">
                    <a href="<?php echo esc_url($facebook); ?>"><i class="fa fa-facebook" aria-hidden="true"></i></a>
                  </li>
                <?php }?>
                <?php if (!empty($twitter)) {?>
                  <li class="list-inline-item">
                    <a href="<?php echo esc_url($twitter); ?>"><i class="fa fa-twitter" aria-hidden="true"></i></a>
                  </li>
                <?php }?>
                <?php if (!empty($linkedin)) {?>
                  <li class="list-inline-item">
                    <a href="<?php echo esc_url($linkedin); ?>"><i class="fa fa-linkedin" aria-hidden="true"></i></a>
                  </li>
                <?php }?>
                <?php if (!empty($instagram)) {?>
                  <li class="list-inline-item">
                    <a href="<?php echo esc_url($instagram); ?>"><i class="fa fa-instagram" aria-hidden="true"></i></a>
                  </li>
                <?php }?>
                <?php if (!empty($pinterest)) {?>
                  <li class="list-inline-item">
                    <a href="<?php echo esc_url($pinterest); ?>"><i class="fa fa-pinterest" aria-hidden="true"></i></a>
                  </li>
                <?php }?>
                <?php if (!empty($tumblr)) {?>
                  <li class="list-inline-item">
                    <a href="<?php echo esc_url($tumblr); ?>"><i class="fa fa-tumblr" aria-hidden="true"></i></a>
                  </li>
                <?php }?>
                <?php if (!empty($googleplus)) {?>
                  <li class="list-inline-item">
                    <a href="<?php echo esc_url($googleplus); ?>"><i class="fa fa-google-plus" aria-hidden="true"></i></a>
                  </li>
                <?php }?>
              </ul>
            </div>

          </div>

        </div>

	  <?php endif;
	  
	}
	
endif;