<?php
/**
 * Sarmaya WooCommerce Customizer Class
 *
 * @package  sarmaya
 * @since 1.0.0
 */

if (!defined('ABSPATH')) {
    exit;
}

if (!class_exists('Sarmaya_WooCommerce_Customizer')):

    /**
     * The Sarmaya Customizer class
     */
    class Sarmaya_WooCommerce_Customizer extends Sarmaya_Customizer {

        /**
         * Setup class.
         *
         * @since 1.0.0
         * @return void
         */
        public function __construct() {
            add_action('customize_register', array($this, 'customize_register'), 10);
            add_action('wp_enqueue_scripts', array($this, 'add_customizer_css'), 130);
            add_filter('sarmaya_setting_default_values', array($this, 'setting_default_values'));
        }

        /**
         * Returns an array of the desired default Sarmaya Options
         *
         * @param array $defaults array of default options.
         * @since 1.0.0
         * @return array
         */
        public function setting_default_values($defaults = array()) {
            $defaults['sarmaya_sticky_add_to_cart'] = true;
            $defaults['sarmaya_product_pagination'] = true;

            return $defaults;
        }

        /**
         * Add postMessage support for site title and description for the Theme Customizer along with several other settings.
         *
         * @param WP_Customize_Manager $wp_customize Theme Customizer object.
         * @since 1.0.0
         */
        public function customize_register($wp_customize) {

            // Add the Product Catalog Page width
            $wp_customize->add_setting('sarmaya_is_woocommerce_catalog_page_fluid', array(
                'default'           => sarmaya_defaults('is_woocommerce_catalog_page_fluid'),
                'sanitize_callback' => 'sarmaya_sanitize_checkbox',
            ));
            $wp_customize->add_control(new ETCode_Toggle_Control($wp_customize, 'sarmaya_is_woocommerce_catalog_page_fluid', array(
                'label'    => esc_html__('Catalog Page Full Width', 'sarmaya'),
                'section'  => 'woocommerce_product_catalog',
                'settings' => 'sarmaya_is_woocommerce_catalog_page_fluid',
                'type'     => 'toggle',
            )));

            // Add Product Catalog Page Layout setting and control.
            $wp_customize->add_setting('sarmaya_woocommerce_product_catalog_layout', array(
                'default'           => sarmaya_defaults('woocommerce_product_catalog_layout'),
                'sanitize_callback' => 'sanitize_key',
            ));
            $wp_customize->add_control(new ETCode_Radio_Image_Control($wp_customize, 'sarmaya_woocommerce_product_catalog_layout', array(
                'label'    => esc_html__('Product Catalog Page Layout', 'sarmaya'),
                'section'  => 'woocommerce_product_catalog',
                'settings' => 'sarmaya_woocommerce_product_catalog_layout',
                'choices'  => array(
                    'left_sidebar'  => array(
                        'label' => esc_html__('Left sidebar', 'sarmaya'),
                        'url'   => '%s/assets/images/admin/left-sidebar.jpg',
                    ),
                    'full_width'    => array(
                        'label' => esc_html__('Full width', 'sarmaya'),
                        'url'   => '%s/assets/images/admin/full-width.jpg',
                    ),
                    'right_sidebar' => array(
                        'label' => esc_html__('Right sidebar', 'sarmaya'),
                        'url'   => '%s/assets/images/admin/right-sidebar.jpg',
                    ),
                ),
            )));

            /***** Woocommerce Single Product Section *****/

            $wp_customize->add_section('sarmaya_woocommerce_single_product', array(
                'title' => esc_html__('Single Product', 'sarmaya'),
                'panel' => 'woocommerce',
            ));

            // Add Single Product Page width
            $wp_customize->add_setting('sarmaya_is_woocommerce_single_product_fluid', array(
                'default'           => sarmaya_defaults('is_woocommerce_single_product_fluid'),
                'sanitize_callback' => 'sarmaya_sanitize_checkbox',
            ));
            $wp_customize->add_control(new ETCode_Toggle_Control($wp_customize, 'sarmaya_is_woocommerce_single_product_fluid', array(
                'label'    => esc_html__('Single Product Page Full Width', 'sarmaya'),
                'section'  => 'sarmaya_woocommerce_single_product',
                'settings' => 'sarmaya_is_woocommerce_single_product_fluid',
                'type'     => 'toggle',
			)));
			
            // Add Single Product Page layout setting and control.
            $wp_customize->add_setting('sarmaya_woocommerce_single_product_layout', array(
                'default'           => sarmaya_defaults('woocommerce_single_product_layout'),
                'sanitize_callback' => 'sanitize_key',
            ));
            $wp_customize->add_control(new ETCode_Radio_Image_Control($wp_customize,
                'sarmaya_woocommerce_single_product_layout',
                array(
                    'label'    => esc_html__('Single Product Page Layout', 'sarmaya'),
                    'section'  => 'sarmaya_woocommerce_single_product',
                    'settings' => 'sarmaya_woocommerce_single_product_layout',
                    'choices'  => array(
                        'left_sidebar'  => array(
                            'label' => esc_html__('Left sidebar', 'sarmaya'),
                            'url'   => '%s/assets/images/admin/left-sidebar.jpg',
                        ),
                        'full_width'    => array(
                            'label' => esc_html__('Full width', 'sarmaya'),
                            'url'   => '%s/assets/images/admin/full-width.jpg',
                        ),
                        'right_sidebar' => array(
                            'label' => esc_html__('Right sidebar', 'sarmaya'),
                            'url'   => '%s/assets/images/admin/right-sidebar.jpg',
                        ),
                    ),
                )));

            /**
             * Product Page
             */
            $wp_customize->add_section(
                'sarmaya_single_product_page', array(
                    'title'    => __('Product Page', 'sarmaya'),
                    'priority' => 60,
                    'panel' => 'woocommerce',
                )
            );

            $wp_customize->add_setting(
                'sarmaya_product_pagination', array(
                    'default'           => apply_filters('sarmaya_default_product_pagination', true),
                    'sanitize_callback' => 'wp_validate_boolean',
                )
            );

            $wp_customize->add_setting(
                'sarmaya_sticky_add_to_cart', array(
                    'default'           => apply_filters('sarmaya_default_sticky_add_to_cart', true),
                    'sanitize_callback' => 'wp_validate_boolean',
                )
            );

            $wp_customize->add_control(
                'sarmaya_sticky_add_to_cart', array(
                    'type'        => 'checkbox',
                    'section'     => 'sarmaya_single_product_page',
                    'label'       => __('Sticky Add-To-Cart', 'sarmaya'),
                    'description' => __('A small content bar at the top of the browser window which includes relevant product information and an add-to-cart button. It slides into view once the standard add-to-cart button has scrolled out of view.', 'sarmaya'),
                    'priority'    => 10,
                )
            );

            $wp_customize->add_control(
                'sarmaya_product_pagination', array(
                    'type'        => 'checkbox',
                    'section'     => 'sarmaya_single_product_page',
                    'label'       => __('Product Pagination', 'sarmaya'),
                    'description' => __('Displays next and previous links on product pages. A product thumbnail is displayed with the title revealed on hover.', 'sarmaya'),
                    'priority'    => 20,
                )
            );
        }


        /**
         * Add CSS in <head> for styles handled by the theme customizer
         *
         * @since 1.0.0
         * @return void
         */
        public function add_customizer_css() {
        }

    }

endif;

return new Sarmaya_WooCommerce_Customizer();
