<?php
/**
 * WooCommerce Template Functions.
 *
 * @package     Sarmaya
 */

if (!function_exists('sarmaya_before_content')) {
    /**
     * Before Content
     * Wraps all WooCommerce content in wrappers which match the theme markup
     *
     * @since   1.0.0
     * @return  void
     */
    function sarmaya_before_content() {

        if (is_single()) {

            $container   = (false === get_theme_mod('sarmaya_is_woocommerce_single_product_fluid', sarmaya_defaults('is_woocommerce_single_product_fluid'))) ? 'container' : 'container-fluid';
            $page_layout = get_theme_mod('sarmaya_woocommerce_single_product_layout', sarmaya_defaults('woocommerce_single_product_layout'));

        } else {

            $container   = (false === get_theme_mod('sarmaya_is_woocommerce_catalog_page_fluid', sarmaya_defaults('is_woocommerce_catalog_page_fluid'))) ? 'container' : 'container-fluid';
            $page_layout = get_theme_mod('sarmaya_woocommerce_product_catalog_layout', sarmaya_defaults('woocommerce_product_catalog_layout'));

        }

        $page_col_size      = $page_layout == 'full_width' ? 'col-lg-12' : 'col-lg-10';
        $page_sidebar_align = $page_layout == 'right_sidebar' ? ' order-2' : ' order-2 order-lg-0';

        ?>

		<div class="<?php echo esc_attr($container); ?> mb-4">
			<div class="row large-gutters">

				<?php if ($page_layout !== 'full_width') {?>
				<div class="col-lg-2 <?php echo esc_attr($page_sidebar_align); ?>">
					<?php woocommerce_get_sidebar();?>
				</div>
				<?php }?>
				<div id="infinite-scroll-container" class="<?php echo esc_attr($page_col_size); ?>">
		<?php
    }
}

if (!function_exists('sarmaya_after_content')) {
    /**
     * After Content
     * Closes the wrapping divs
     *
     * @since   1.0.0
     * @return  void
     */
    function sarmaya_after_content() {
        ?>
				</div>
			</div>
		</div>

		<?php
        do_action('sarmaya_sidebar');
    }
}

// Add div product_img_wrapper for product image, add to cart btn and sale flash
if (!function_exists('sarmaya_woocommerce_template_loop_product_img_wrapper_open')) {
    /**
     * Insert the opening img_wrapper tag for products in the loop.
     */
    function sarmaya_woocommerce_template_loop_product_img_wrapper_open() {
        echo '<div class="product-img-wrapper">';
    }
}

if (!function_exists('sarmaya_woocommerce_template_loop_product_img_wrapper_close')) {
    /**
     * Insert the close img_wrapper tag for products in the loop.
     */
    function sarmaya_woocommerce_template_loop_product_img_wrapper_close() {
        echo '</div>';
    }
}

// Add div wrappe for title and sale price
if (!function_exists('sarmaya_woocommerce_template_loop_product_title_price_wrapper_open')) {
    function sarmaya_woocommerce_template_loop_product_title_price_wrapper_open() {
        echo '<div class="product-content-wrapper">';
    }
}

if (!function_exists('sarmaya_woocommerce_template_loop_product_title_price_wrapper_close')) {
    function sarmaya_woocommerce_template_loop_product_title_price_wrapper_close() {
        echo '</div>';
    }
}

/**
 * Checkout
 *
 */

if (!function_exists('sarmaya_checkout_before_order_review')) {
    /**
     * order_review_heading
     * in woocommerce_checkout_before_order_review
     *
     * @since   1.0.0
     * @return  void
     */
    function sarmaya_checkout_before_order_review() {
        ?>
		<div class="order_review_container">
		<?php
    }
}

if (!function_exists('sarmaya_checkout_order_review_title')) {
    /**
     * order_review_heading
     * in woocommerce_checkout_order_review
     *
     * @since   1.0.0
     * @return  void
     */
    function sarmaya_checkout_order_review_title() {
        ?>
		<h3 class="order_review_heading"><?php esc_html_e('Your order', 'sarmaya');?></h3>
		<?php
    }
}

if (!function_exists('sarmaya_checkout_after_order_review')) {
    /**
     * order_review_heading
     * in woocommerce_checkout_after_order_review
     *
     * @since   1.0.0
     * @return  void
     */
    function sarmaya_checkout_after_order_review() {
        ?>
		</div>
		<?php
    }
}

if (!function_exists('sarmaya_cart_link_fragment')) {
    /**
     * Cart Fragments
     * Ensure cart contents update when products are added to the cart via AJAX
     *
     * @param  array $fragments Fragments to refresh via AJAX.
     * @return array            Fragments to refresh via AJAX
     */
    function sarmaya_cart_link_fragment($fragments) {
        global $woocommerce;

        ob_start();
        echo sarmaya_cart_link();
        $fragments['a.cart-contents'] = ob_get_clean();

        return $fragments;
    }
}

if (!function_exists('sarmaya_cart_link')) {
    /**
     * Cart Link
     * Displayed a link to the cart including the number of items present and the cart total
     *
     * @return void
     * @since  1.0.0
     */
    function sarmaya_cart_link() {

        $return = '<a class="cart-contents dropdown-toggle nav-link" href="#" data-toggle="dropdown" aria-haspopup="true" aria-expanded="false" title=" ' . esc_attr('View your shopping cart', 'sarmaya') . ' ">';
        $return .= '<i class="fas fa-shopping-cart"></i>' . esc_html__('Cart', 'sarmaya') ;
       
        $return .= '<span class="cart-count badge badge-pill badge-light">';
        $return .= WC()->cart->get_cart_contents_count();
        $return .= '</span>';

        $return .= '</a>';

        return $return;

    }
}

if (!function_exists('sarmaya_product_search')) {
    /**
     * Display Product Search
     *
     * @since  1.0.0
     * @uses  sarmaya_is_woocommerce_activated() check if WooCommerce is activated
     * @return void
     */
    function sarmaya_product_search() {
        if (sarmaya_is_woocommerce_activated()) {
            ?>
			<div class="site-search">
				<?php the_widget('WC_Widget_Product_Search', 'title=');?>
			</div>
			<?php
        }
    }
}

if (!function_exists('sarmaya_header_cart')) {
    /**
     * Display Header Cart
     *
     * @since  1.0.0
     * @uses  sarmaya_is_woocommerce_activated() check if WooCommerce is activated
     * @return void
     */
    function sarmaya_header_cart() {

        if (sarmaya_is_woocommerce_activated()) {

            $return = '<li class="menu-item dropdown d-lg-flex align-items-center nav-item nav-item-cart">';
            
            $return .= sarmaya_cart_link();
            
            $return .= '<form id="site-header-cart" class="site-header-cart dropdown-menu dropdown-menu-right">';

            $return .= '<div class="widget_shopping_cart_content"></div>';

            $return .= '</form>';

            $return .= '</li>';

            return $return;

        }
    }
}

if (!function_exists('sarmaya_product_columns_wrapper')) {
    /**
     * Product columns wrapper
     *
     * @since 1.0.0
     * @return  void
     */
    function sarmaya_product_columns_wrapper() {
        $columns = sarmaya_loop_columns();
        echo '<div class="columns-' . absint($columns) . '">';
    }
}

if (!function_exists('sarmaya_loop_columns')) {
    /**
     * Default loop columns on product archives
     *
     * @return integer products per row
     * @since  1.0.0
     */
    function sarmaya_loop_columns() {
        $columns = 3; // 3 products per row

        if (function_exists('wc_get_default_products_per_row')) {
            $columns = wc_get_default_products_per_row();
        }

        return apply_filters('sarmaya_loop_columns', $columns);
    }
}

if (!function_exists('sarmaya_product_columns_wrapper_close')) {
    /**
     * Product columns wrapper close
     *
     * @since 1.0.0
     * @return  void
     */
    function sarmaya_product_columns_wrapper_close() {
        echo '</div>';
    }
}

if (!function_exists('sarmaya_promoted_products')) {
    /**
     * Featured and On-Sale Products
     * Check for featured products then on-sale products and use the appropiate shortcode.
     * If neither exist, it can fallback to show recently added products.
     *
     * @since  1.5.1
     * @param integer $per_page total products to display.
     * @param integer $columns columns to arrange products in to.
     * @param boolean $recent_fallback Should the function display recent products as a fallback when there are no featured or on-sale products?.
     * @uses  sarmaya_is_woocommerce_activated()
     * @uses  wc_get_featured_product_ids()
     * @uses  wc_get_product_ids_on_sale()
     * @uses  sarmaya_do_shortcode()
     * @return void
     */
    function sarmaya_promoted_products($per_page = '2', $columns = '2', $recent_fallback = true) {
        if (sarmaya_is_woocommerce_activated()) {

            if (wc_get_featured_product_ids()) {

                echo '<h2>' . esc_html__('Featured Products', 'sarmaya') . '</h2>';

                echo sarmaya_do_shortcode(
                    'featured_products', array(
                        'per_page' => $per_page,
                        'columns'  => $columns,
                    )
                ); // WPCS: XSS ok.
            } elseif (wc_get_product_ids_on_sale()) {

                echo '<h2>' . esc_html__('On Sale Now', 'sarmaya') . '</h2>';

                echo sarmaya_do_shortcode(
                    'sale_products', array(
                        'per_page' => $per_page,
                        'columns'  => $columns,
                    )
                ); // WPCS: XSS ok.
            } elseif ($recent_fallback) {

                echo '<h2>' . esc_html__('New In Store', 'sarmaya') . '</h2>';

                echo sarmaya_do_shortcode(
                    'recent_products', array(
                        'per_page' => $per_page,
                        'columns'  => $columns,
                    )
                ); // WPCS: XSS ok.
            }
        }
    }
}

if (!function_exists('sarmaya_handheld_footer_bar_search')) {
    /**
     * The search callback function for the handheld footer bar
     *
     * @since 1.0.0
     */
    function sarmaya_handheld_footer_bar_search() {
        echo '<a href="">' . esc_attr__('Search', 'sarmaya') . '</a>';
        sarmaya_product_search();
    }
}

if (!function_exists('sarmaya_handheld_footer_bar_cart_link')) {
    /**
     * The cart callback function for the handheld footer bar
     *
     * @since 1.0.0
     */
    function sarmaya_handheld_footer_bar_cart_link() {
        ?>
			<a class="footer-cart-contents" href="<?php echo esc_url(wc_get_cart_url()); ?>" title="<?php esc_attr_e('View your shopping cart', 'sarmaya');?>">
				<span class="count"><?php echo wp_kses_data(WC()->cart->get_cart_contents_count()); ?></span>
			</a>
		<?php
    }
}

if (!function_exists('sarmaya_handheld_footer_bar_account_link')) {
    /**
     * The account callback function for the handheld footer bar
     *
     * @since 1.0.0
     */
    function sarmaya_handheld_footer_bar_account_link() {
        echo '<a href="' . esc_url(get_permalink(get_option('woocommerce_myaccount_page_id'))) . '">' . esc_html__('My Account', 'sarmaya') . '</a>';
    }
}
